[PO_Project]
user = {{ USERNAME }}
password = {{ PASSWORD }}
host = {{ SERVICE_URL }}
locale_path = {{ project_locale_path }}
project_slug = {{ project_slug }}
kind = {{ project_kind }}
django_default_locale = {{ default_locale_dir }}
