<div class="row index-items equal-heights divider">
    <div class="medium-4 columns item">
        <h4>Item 1</h4>
        <div class="content equalized-item">
            <a href=""><img src="http://placehold.it/220x125" class="centered" alt=""></a>
        </div>
        <p class="text-center"><a class="button radius secondary" href="#">Item link</a></p>
    </div>
    
    <div class="medium-4 columns item">
        <h4>Item 2</h4>
        <div class="content equalized-item">
            <a href=""><img src="http://placehold.it/220x125" class="centered" alt=""></a>
        </div>
        <p class="text-center"><a class="button radius secondary" href="#">Item link</a></p>
    </div>
    
    <div class="medium-4 columns item">
        <h4>Item 3</h4>
        <div class="content equalized-item">
            <a href=""><img src="http://placehold.it/220x125" class="centered" alt=""></a>
        </div>
        <p class="text-center"><a class="button radius secondary" href="#">Item link</a></p>
    </div>
</div>