{% extends "registration/base.html" %}
{% load i18n %}

{% block content %}
    <div class="row">
        <div class="six columns centered">
            <h2>{% trans "Your are logged out" %}</h2>
        </div>
    </div>
{% endblock %}
