{% load i18n %}
{% with category=object.categories.all.0 %}
<div class="large-4 columns item news">
    <div class="wrap equalized-item">
        <h2 class="badge">{{ category.title }}</h2>
        <ul class="feed">{% for object in entries %}<li>
            <h3><a href="{{ object.get_absolute_url }}" title="{{ object.title }}" rel="bookmark">{{ object.title }}</a></h3>
        </li>{% empty %}<li class="empty">{% trans "No entries yet." %}</li>
        {% endfor %}</ul>
    </div>
</div>
{% endwith %}
