"""
`Django Blog Zinnia`_ allows for the management of a blog in your project. It is perfectly integrated into the `cms`_ component but can also be used independently.

At the time of installation, an automatic patch (that can be viewed in the ``patches/`` directory) is applied to it to implement the use of `ckeditor`_, which is enabled by default in its settings.
"""