{% extends "skeleton.html" %}

{% block base_content %}
<div class="row">
    <h2>Prototypes</h2>

    <ul>{% for url_pattern,template_name,url_name in page_map %}
        <li><a href="{% url url_name %}">{{ template_name }}</a></li>
    {% endfor %}</ul>
</div>
{% endblock %}