{% extends "registration/base.html" %}
{% load i18n crispy_forms_tags %}

{% block content %}
    <div class="row">
        <div class="six columns centered">
            <h2>{% trans "Password change" %}</h2>
            <form method="post" action="." class="simple">
                <div class="row">
                    <div class="twelve columns">
                        {% crispy form %}
                    </div>
                </div>

                <div class="row">
                    <div class="twelve columns text-right">
                        <input type="submit" class="submit button" value="{% trans 'Submit' %}">
                    </div>
                </div>
            </form>

        </div>
    </div>
{% endblock %}
