<div class="row row-fluid">
    <div data-interchange=" [{% url 'slideshows:random_slide' slug=slideshow_instance.slug %}, (medium)], [{% url 'slideshows:random_slide' slug=slideshow_instance.slug %}, (large)]" id="interchanged-content-intro"></div>
</div>
