<div class="row index-intro equal-heights divider">
    <div class="small-12 visual columns">
        <img src="http://placehold.it/1000x400" class="centered" alt="">
    </div>
    <div class="medium-4 columns item equalized-item">
        <h2>Title 1</h2>
        <p>30, 34 rue du quatre Septembre,<br>75002 Paris ( M° Opéra, Quatre Septembre,<br>Pyramides, Bourse )</p>
        <p>Pellentesque habitant morbi tristique <br>senectus et netus et malesuada fames <br>ac turpis egestas.</p>
        <p class="text-center"><a class="button secondary" href="">Button 1</a></p>
    </div>
    <div class="medium-4 columns item equalized-item">
        <h2>Title 2</h2>
        <p>Praesent dignissim convallis dolor vel congue.</p>
    </div>
    <div class="medium-4 columns item equalized-item">
        <h2>Title 3</h2>
        <p>Tel : +33 (0)1 01 01 01 01</p>
        <p class="text-center"><a class="button secondary" href="">Button 3.1</a></p>
        <p class="text-center"><a class="button secondary" href="">Button 3.2</a></p>
    </div>
</div>
