<a href="#" class="button dropdown trick">Dropdown Button</a>
<ul class="f-dropdown">
    <li><a href="#">This is a link</a></li>
    <li><a href="#">This is another</a></li>
    <li><a href="#">Yet another</a></li>
</ul>