/* The SCSS where fonts are loaded and existing icons are declared, need to 
 * import the base before
 */
@import "components/font-awesome_base";

// Customized fonts set of "Awesome fonts" + "Awesome fonts more" made 
// from http://icomoon.io/app/
@font-face {
    font-family: 'fontawesome';
    src:url('#{$fontAwesomePath}/fontawesome.eot');
    src:url('#{$fontAwesomePath}/fontawesome.eot?#iefix') format('embedded-opentype'),
        url('#{$fontAwesomePath}/fontawesome.woff') format('woff'),
        url('#{$fontAwesomePath}/fontawesome.ttf') format('truetype'),
        url('#{$fontAwesomePath}/fontawesome.svg#fontawesome') format('svg');
    font-weight: normal;
    font-style: normal;
}

.icon-youtube:before {
    content: "\f30e";
}
.icon-facebook:before {
    content: "\f09a";
}
.icon-twitter:before {
    content: "\f099";
}
.icon-search:before {
    content: "\f002";
}
.icon-google-plus:before {
    content: "\f0d5";
}
.icon-chevron-left:before {
    content: "\f053";
}
.icon-chevron-right:before {
    content: "\f054";
}
.icon-apple:before {
    content: "\f344";
}
.icon-android:before {
    content: "\f342";
}
.icon-acrobat:before {
    content: "\f206";
}
.icon-download-alt:before {
    content: "\f019";
}
.icon-refresh:before {
    content: "\f021";
}
.icon-question-sign:before {
    content: "\f059";
}
.icon-volume-up:before {
    content: "\f028";
}
.icon-picture:before {
    content: "\f03e";
}
