<div class="mosaic-rows divider">
    <div class="row">
        <h2 class="underlined"><strong>Title</strong></h2>

        <div class="small-6 medium-3 visual columns">
            <a href="#"><img src="http://placehold.it/240x177" class="centered" alt=""></a>
            <p class="bottomline"><a href="#">Item 1</a></p>
        </div>
        <div class="small-6 medium-3 visual columns">
            <a href="#"><img src="http://placehold.it/240x177" class="centered" alt=""></a>
            <p class="bottomline"><a href="#">Item 2</a></p>
        </div>
        <div class="small-6 medium-3 visual columns">
            <a href="#"><img src="http://placehold.it/240x177" class="centered" alt=""></a>
            <p class="bottomline"><a href="#">Item 3</a></p>
        </div>
        <div class="small-6 medium-3 visual columns">
            <a href="#"><img src="http://placehold.it/240x177" class="centered" alt=""></a>
            <p class="bottomline"><a href="#">Item 4</a></p>
        </div>
    </div>
</div>
