@charset "UTF-8";

@import "settings";
@import "compass";

/*
 * Consistant colors names facility
 */
$white:#ffffff;
$black:#000000;

// Full foundation components import
@import "foundation";
/*
 * All foundation components, one by one
*/
/*
@import
  "foundation/components/grid",
  "foundation/components/accordion",
  "foundation/components/alert-boxes",
  "foundation/components/block-grid",
  "foundation/components/breadcrumbs",
  "foundation/components/button-groups",
  "foundation/components/buttons",
  "foundation/components/clearing",
  "foundation/components/dropdown",
  "foundation/components/dropdown-buttons",
  "foundation/components/flex-video",
  "foundation/components/forms",
  "foundation/components/icon-bar",
  "foundation/components/inline-lists",
  "foundation/components/joyride",
  "foundation/components/keystrokes",
  "foundation/components/labels",
  "foundation/components/magellan",
  "foundation/components/orbit",
  "foundation/components/pagination",
  "foundation/components/panels",
  "foundation/components/pricing-tables",
  "foundation/components/progress-bars",
  "foundation/components/range-slider",
  "foundation/components/reveal",
  "foundation/components/side-nav",
  "foundation/components/split-buttons",
  "foundation/components/sub-nav",
  "foundation/components/switches",
  "foundation/components/tables",
  "foundation/components/tabs",
  "foundation/components/thumbs",
  "foundation/components/tooltips",
  "foundation/components/top-bar",
  "foundation/components/type",
  "foundation/components/offcanvas",
  "foundation/components/visibility";
*/

/* 
 * Addon Components
 */
@import "components/addons";
//@import "components/icomoon";
//@import "components/spinner";
//@import "components/magnific-popup";
//@import "components/royalSlider";

#body_content{
    //@import "components/porticus";
    //@import "components/socialaggregator";
    //@import "components/zinnia";
    @import "components/contents";
}
