{% extends "registration/base.html" %}
{% load i18n %}

{% block content %}
    <div class="row">
        <div class="six columns centered">
            <h2>{% trans "Password change" %}</h2>

            <p>{% trans "Password has been changed" %}</p>
        </div>
    </div>
{% endblock %}
