@charset "UTF-8";
/* 
 * Minimal CSS, contain all the content layout but not the header nor the 
 * footer. Used in djangocms page render in admin
 */
/*
 * Settings file containing Foundation settings
 * Inherit from the Foundation default settings, so uncomment only what you 
 * want to override
 */
/* line 55, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_semantic-grid.scss */
.row-fluid {
  *zoom: 1;
}
/* line 4, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
.row-fluid:before, .row-fluid:after {
  content: " ";
  display: table;
}
/* line 5, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
.row-fluid:after {
  clear: both;
}

/* Requires: normalize.css */
/* Global Reset & Standards ---------------------- */
/* line 5, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
*, *:before, *:after {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

/* line 6, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
html {
  font-size: 62.5%;
}

/* line 7, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
body {
  background: white;
  font-family: "Open Sans", Arial, Helvetica, Verdana, sans-serif;
  font-weight: normal;
  font-style: normal;
  font-size: 14px;
  line-height: 1;
  color: #222222;
  position: relative;
  -webkit-font-smoothing: antialiased;
}

/* Links ---------------------- */
/* line 11, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
a img {
  border: none;
}

/* line 12, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
a {
  color: #fd9c00;
  text-decoration: none;
  line-height: inherit;
}

/* line 13, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
a:hover {
  color: #e48c00;
}

/* line 14, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
a:focus {
  color: #e48c00;
}

/* line 15, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
p a, p a:visited {
  line-height: inherit;
}

/* Misc ---------------------- */
/* line 19, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
.left {
  float: left;
}

/* line 20, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
.right {
  float: right;
}

/* line 21, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
.text-left {
  text-align: left;
}

/* line 22, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
.text-right {
  text-align: right;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
.text-center {
  text-align: center;
}

/* line 24, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
.hide {
  display: none;
}

/* line 25, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
.hide-override {
  display: none !important;
}

/* line 26, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
.highlight {
  background: #ffff99;
}

/* line 28, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
#googlemap img, object, embed {
  max-width: none;
}

/* line 30, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
#map_canvas embed {
  max-width: none;
}

/* line 31, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
#map_canvas img {
  max-width: none;
}

/* line 32, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
#map_canvas object {
  max-width: none;
}

/* Reset for strange margins by default on <figure> elements */
/* line 35, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_globals.scss */
figure {
  margin: 0;
}

/* The Grid ---------------------- */
/* line 3, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row {
  width: 1000px;
  max-width: 100%;
  min-width: 768px;
  margin: 0 auto;
}
/* line 4, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .row {
  width: auto;
  max-width: none;
  min-width: 0;
  margin: 0 -15px;
}
/* line 7, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row.collapse .column, .row.collapse .columns {
  padding: 0;
}
/* line 9, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .row {
  width: auto;
  max-width: none;
  min-width: 0;
  margin: 0 -15px;
}
/* line 10, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .row.collapse {
  margin: 0;
}

/* line 14, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.column, .columns {
  float: left;
  min-height: 1px;
  padding: 0 15px;
  position: relative;
}
/* line 15, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.column.centered, .columns.centered {
  float: none;
  margin: 0 auto;
}

/* line 18, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
[class*="column"] + [class*="column"]:last-child {
  float: right;
}

/* line 19, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
[class*="column"] + [class*="column"].end {
  float: left;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.one, .row .one {
  width: 8.33333%;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.two, .row .two {
  width: 16.66667%;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.three, .row .three {
  width: 25%;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.four, .row .four {
  width: 33.33333%;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.five, .row .five {
  width: 41.66667%;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.six, .row .six {
  width: 50%;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.seven, .row .seven {
  width: 58.33333%;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.eight, .row .eight {
  width: 66.66667%;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.nine, .row .nine {
  width: 75%;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.ten, .row .ten {
  width: 83.33333%;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.eleven, .row .eleven {
  width: 91.66667%;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.twelve, .row .twelve {
  width: 100%;
}

/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .offset-by-one {
  margin-left: 8.33333%;
}

/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .offset-by-two {
  margin-left: 16.66667%;
}

/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .offset-by-three {
  margin-left: 25%;
}

/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .offset-by-four {
  margin-left: 33.33333%;
}

/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .offset-by-five {
  margin-left: 41.66667%;
}

/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .offset-by-six {
  margin-left: 50%;
}

/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .offset-by-seven {
  margin-left: 58.33333%;
}

/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .offset-by-eight {
  margin-left: 66.66667%;
}

/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .offset-by-nine {
  margin-left: 75%;
}

/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row .offset-by-ten {
  margin-left: 83.33333%;
}

/* line 42, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.push-two {
  left: 16.66667%;
}

/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.pull-two {
  right: 16.66667%;
}

/* line 42, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.push-three {
  left: 25%;
}

/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.pull-three {
  right: 25%;
}

/* line 42, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.push-four {
  left: 33.33333%;
}

/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.pull-four {
  right: 33.33333%;
}

/* line 42, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.push-five {
  left: 41.66667%;
}

/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.pull-five {
  right: 41.66667%;
}

/* line 42, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.push-six {
  left: 50%;
}

/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.pull-six {
  right: 50%;
}

/* line 42, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.push-seven {
  left: 58.33333%;
}

/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.pull-seven {
  right: 58.33333%;
}

/* line 42, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.push-eight {
  left: 66.66667%;
}

/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.pull-eight {
  right: 66.66667%;
}

/* line 42, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.push-nine {
  left: 75%;
}

/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.pull-nine {
  right: 75%;
}

/* line 42, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.push-ten {
  left: 83.33333%;
}

/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.pull-ten {
  right: 83.33333%;
}

/* line 46, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
img {
  height: auto;
}

/* line 47, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
img, object, embed {
  max-width: 100%;
}

/* line 48, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
img {
  -ms-interpolation-mode: bicubic;
}

/* line 49, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
#map_canvas img, .map_canvas img {
  max-width: none!important;
}

/* Nicolas Gallagher's micro clearfix */
/* line 52, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.row {
  *zoom: 1;
}
/* line 4, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
.row:before, .row:after {
  content: " ";
  display: table;
}
/* line 5, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
.row:after {
  clear: both;
}

/* Block Grids ---------------------- */
/* These are 2-up, 3-up, 4-up and 5-up ULs, suited
for repeating blocks of content. Add 'mobile' to
them to switch them just like the layout grid
(one item per line) on phones

For IE7/8 compatibility block-grid items need to be
the same height. You can optionally uncomment the
lines below to support arbitrary height, but know
that IE7/8 do not support :nth-child.
-------------------------------------------------- */
/* line 67, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid {
  display: block;
  overflow: hidden;
  padding: 0;
}
/* line 69, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid > li {
  display: block;
  height: auto;
  float: left;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.one-up {
  margin: 0;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.one-up > li {
  width: 100%;
  padding: 0 0 15px;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.two-up {
  margin: 0 -15px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.two-up > li {
  width: 50%;
  padding: 0 15px 15px;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.two-up > li:nth-child(2n+1) {
  clear: both;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.three-up {
  margin: 0 -12px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.three-up > li {
  width: 33.33333%;
  padding: 0 12px 12px;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.three-up > li:nth-child(3n+1) {
  clear: both;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.four-up {
  margin: 0 -10px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.four-up > li {
  width: 25%;
  padding: 0 10px 10px;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.four-up > li:nth-child(4n+1) {
  clear: both;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.five-up {
  margin: 0 -8px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.five-up > li {
  width: 20%;
  padding: 0 8px 8px;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.five-up > li:nth-child(5n+1) {
  clear: both;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.six-up {
  margin: 0 -8px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.six-up > li {
  width: 16.66667%;
  padding: 0 8px 8px;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.six-up > li:nth-child(6n+1) {
  clear: both;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.seven-up {
  margin: 0 -8px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.seven-up > li {
  width: 14.28571%;
  padding: 0 8px 8px;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.seven-up > li:nth-child(7n+1) {
  clear: both;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.eight-up {
  margin: 0 -8px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.eight-up > li {
  width: 12.5%;
  padding: 0 8px 8px;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.eight-up > li:nth-child(8n+1) {
  clear: both;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.nine-up {
  margin: 0 -8px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.nine-up > li {
  width: 11.11111%;
  padding: 0 8px 8px;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.nine-up > li:nth-child(9n+1) {
  clear: both;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.ten-up {
  margin: 0 -8px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.ten-up > li {
  width: 10%;
  padding: 0 8px 8px;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.ten-up > li:nth-child(10n+1) {
  clear: both;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.eleven-up {
  margin: 0 -8px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.eleven-up > li {
  width: 9.09091%;
  padding: 0 8px 8px;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.eleven-up > li:nth-child(11n+1) {
  clear: both;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.twelve-up {
  margin: 0 -8px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.twelve-up > li {
  width: 8.33333%;
  padding: 0 8px 8px;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/_grid.scss */
.block-grid.twelve-up > li:nth-child(12n+1) {
  clear: both;
}

/* Base Type Styles Using Modular Scale ---------------------- */
/* line 3, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
body, div, dl, dt, dd, ul, ol, li, h1, h2, h3, h4, h5, h6, pre, form, p, blockquote, th, td {
  margin: 0;
  padding: 0;
  font-size: 14px;
  direction: ltr;
}

/* line 10, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
p {
  font-family: inherit;
  font-weight: normal;
  font-size: 14px;
  line-height: 1.6;
  margin-bottom: 17px;
}
/* line 11, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
p.lead {
  font-size: 17.5px;
  line-height: 1.6;
  margin-bottom: 17px;
}

/* line 13, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
aside p {
  font-size: 13px;
  line-height: 1.35;
  font-style: italic;
}

/* line 15, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
h1, h2, h3, h4, h5, h6 {
  font-family: "Open Sans", Arial, Helvetica, Verdana, sans-serif;
  font-weight: bold;
  font-style: normal;
  color: #222222;
  text-rendering: optimizeLegibility;
  line-height: 1.1;
  margin-bottom: 14px;
  margin-top: 14px;
}
/* line 24, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
h1 small, h2 small, h3 small, h4 small, h5 small, h6 small {
  font-size: 60%;
  color: #6f6f6f;
  line-height: 0;
}

/* line 27, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
h1 {
  font-size: 44px;
}

/* line 28, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
h2 {
  font-size: 37px;
}

/* line 29, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
h3 {
  font-size: 27px;
}

/* line 30, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
h4 {
  font-size: 23px;
}

/* line 31, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
h5 {
  font-size: 17px;
}

/* line 32, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
h6 {
  font-size: 14px;
}

/* line 34, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
hr {
  border: solid #ddd;
  border-width: 1px 0 0;
  clear: both;
  margin: 22px 0 21px;
  height: 0;
}

/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
.subheader {
  line-height: 1.3;
  color: #6f6f6f;
  font-weight: 300;
  margin-bottom: 17px;
}

/* line 38, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
em, i {
  font-style: italic;
  line-height: inherit;
}

/* line 39, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
strong, b {
  font-weight: bold;
  line-height: inherit;
}

/* line 40, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
small {
  font-size: 60%;
  line-height: inherit;
}

/* line 41, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
code {
  font-weight: bold;
  background: #ffff99;
}

/* Lists ---------------------- */
/* line 44, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ul, ol, dl {
  font-size: 14px;
  line-height: 1.6;
  margin-bottom: 17px;
  list-style-position: outside;
}

/* line 47, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ul li ul, ul li ol {
  margin-left: 20px;
  margin-bottom: 0;
}
/* line 49, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ul.square, #content-main .index-intro-2 .content ul, #content-main .index-items .item ul, ul.circle, ul.disc {
  margin-left: 17px;
}
/* line 50, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ul.square, #content-main .index-intro-2 .content ul, #content-main .index-items .item ul {
  list-style-type: square;
}
/* line 51, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ul.square li ul, #content-main .index-intro-2 .content ul li ul, #content-main .index-items .item ul li ul {
  list-style: inherit;
}
/* line 53, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ul.circle {
  list-style-type: circle;
}
/* line 54, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ul.circle li ul {
  list-style: inherit;
}
/* line 56, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ul.disc {
  list-style-type: disc;
}
/* line 57, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ul.disc li ul {
  list-style: inherit;
}
/* line 59, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ul.no-bullet {
  list-style: none;
}
/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ul.large li {
  line-height: 21px;
}

/* line 62, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ol {
  margin-left: 20px;
}
/* line 64, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
ol li ul, ol li ol {
  margin-left: 20px;
  margin-bottom: 0;
}

/* Blockquotes ---------------------- */
/* line 69, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
blockquote, blockquote p {
  line-height: 1.5;
  color: #6f6f6f;
}

/* line 70, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
blockquote {
  margin: 0 0 17px;
  padding: 9px 20px 0 19px;
  border-left: 1px solid #ddd;
}
/* line 71, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
blockquote cite {
  display: block;
  font-size: 13px;
  color: #555555;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
blockquote cite:before {
  content: "\2014 \0020";
}
/* line 73, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
blockquote cite a, blockquote cite a:visited {
  color: #555555;
}

/* line 77, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
abbr, acronym {
  text-transform: uppercase;
  font-size: 90%;
  color: #222222;
  border-bottom: 1px solid #ddd;
  cursor: help;
}

/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
abbr {
  text-transform: none;
}

/*
 * Print styles.
 *
 * Inlined to avoid required HTTP connection: www.phpied.com/delay-loading-your-print-css/
 * Credit to Paul Irish and HTML5 Boilerplate (html5boilerplate.com)
*/
/* line 86, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
.print-only {
  display: none !important;
}

@media print {
  /* line 88, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  * {
    background: transparent !important;
    color: black !important;
    box-shadow: none !important;
    text-shadow: none !important;
    filter: none !important;
    -ms-filter: none !important;
  }

  /* Black prints faster: h5bp.com/s */
  /* line 89, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  a, a:visited {
    text-decoration: underline;
  }

  /* line 90, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  a[href]:after {
    content: " (" attr(href) ")";
  }

  /* line 91, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  abbr[title]:after {
    content: " (" attr(title) ")";
  }

  /* line 92, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  .ir a:after, a[href^="javascript:"]:after, a[href^="#"]:after {
    content: "";
  }

  /* Don't show links for images, or javascript/internal links */
  /* line 93, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  pre, blockquote {
    border: 1px solid #999;
    page-break-inside: avoid;
  }

  /* line 94, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  thead {
    display: table-header-group;
  }

  /* h5bp.com/t */
  /* line 95, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  tr, img {
    page-break-inside: avoid;
  }

  /* line 96, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  img {
    max-width: 100% !important;
  }

  @page {
    margin: 0.5cm;
}

  /* line 98, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  p, h2, h3 {
    orphans: 3;
    widows: 3;
  }

  /* line 99, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  h2, h3 {
    page-break-after: avoid;
  }

  /* line 100, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  .hide-on-print {
    display: none !important;
  }

  /* line 101, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  .print-only {
    display: block !important;
  }

  /* line 102, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  .hide-for-print {
    display: none !important;
  }

  /* line 103, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_typography.scss */
  .show-for-print {
    display: inherit !important;
  }
}
/* Requires
   globals.css */
/* Standard Forms ---------------------- */
/* line 6, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form {
  margin: 0 0 19.41641px;
}

/* line 8, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.row form .row {
  margin: 0 -6px;
}
/* line 10, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.row form .row .column, .row form .row .columns {
  padding: 0 6px;
}
/* line 12, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.row form .row.collapse {
  margin: 0;
}
/* line 13, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.row form .row.collapse .column, .row form .row.collapse .columns {
  padding: 0;
}

/* line 17, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
label {
  font-size: 14px;
  color: #4d4d4d;
  cursor: pointer;
  display: block;
  font-weight: 500;
  margin-bottom: 3px;
}
/* line 19, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
label.right {
  float: none;
  text-align: right;
}
/* line 20, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
label.inline {
  line-height: 32px;
  margin: 0 0 12px 0;
}

/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.prefix, .postfix {
  display: block;
  position: relative;
  z-index: 2;
  text-align: center;
  width: 100%;
  padding-top: 0;
  padding-bottom: 0;
  height: 32px;
  line-height: 31px;
}

/* line 24, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
a.button.prefix, a.button.postfix {
  padding-left: 0;
  padding-right: 0;
  text-align: center;
}

/* line 25, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
span.prefix, span.postfix {
  background: #f2f2f2;
  border: 1px solid #cccccc;
}

/* line 27, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.prefix {
  left: 2px;
  -moz-border-radius-topleft: 2px;
  -webkit-border-top-left-radius: 2px;
  border-top-left-radius: 2px;
  -moz-border-radius-bottomleft: 2px;
  -webkit-border-bottom-left-radius: 2px;
  border-bottom-left-radius: 2px;
  overflow: hidden;
}

/* line 28, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.postfix {
  right: 2px;
  -moz-border-radius-topright: 2px;
  -webkit-border-top-right-radius: 2px;
  border-top-right-radius: 2px;
  -moz-border-radius-bottomright: 2px;
  -webkit-border-bottom-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

/* line 30, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
input[type="text"], input[type="password"], input[type="date"], input[type="datetime"], input[type="email"], input[type="number"], input[type="search"], input[type="tel"], input[type="time"], input[type="url"], textarea {
  background-color: white;
  font-family: inherit;
  border: 1px solid #cccccc;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  -ms-border-radius: 2px;
  -o-border-radius: 2px;
  border-radius: 2px;
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  color: rgba(0, 0, 0, 0.75);
  display: block;
  font-size: 14px;
  margin: 0 0 12px 0;
  padding: 6px;
  height: 32px;
  width: 100%;
  -webkit-transition: all 0.15s linear;
  -moz-transition: all 0.15s linear;
  -o-transition: all 0.15s linear;
  transition: all 0.15s linear;
}
/* line 32, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
input[type="text"].oversize, input[type="password"].oversize, input[type="date"].oversize, input[type="datetime"].oversize, input[type="email"].oversize, input[type="number"].oversize, input[type="search"].oversize, input[type="tel"].oversize, input[type="time"].oversize, input[type="url"].oversize, textarea.oversize {
  font-size: 17px;
  padding: 4px 6px;
}
/* line 34, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
input[type="text"]:focus, input[type="password"]:focus, input[type="date"]:focus, input[type="datetime"]:focus, input[type="email"]:focus, input[type="number"]:focus, input[type="search"]:focus, input[type="tel"]:focus, input[type="time"]:focus, input[type="url"]:focus, textarea:focus {
  background: #fafafa;
  border-color: #b3b3b3;
}
/* line 35, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
input[type="text"][disabled], input[type="password"][disabled], input[type="date"][disabled], input[type="datetime"][disabled], input[type="email"][disabled], input[type="number"][disabled], input[type="search"][disabled], input[type="tel"][disabled], input[type="time"][disabled], input[type="url"][disabled], textarea[disabled] {
  background-color: #ddd;
}

/* line 38, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
textarea {
  height: auto;
}

/* line 40, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
select {
  width: 100%;
}

/* Fieldsets */
/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
fieldset {
  border: solid 1px #ddd;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  padding: 12px;
  margin: 18px 0;
}
/* line 45, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
fieldset legend {
  font-weight: bold;
  background: white;
  padding: 0 3px;
  margin: 0;
  margin-left: -3px;
}

/* Errors */
/* line 49, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.error input, input.error, .error textarea, textarea.error, .error input:focus, input.error:focus, .error textarea:focus, textarea.error:focus {
  border-color: #c60f13;
  background-color: rgba(198, 15, 19, 0.1);
}

/* line 50, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.error input:focus, input.error:focus, .error textarea:focus, textarea.error:focus {
  outline-color: #f5797c;
}

/* line 51, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.error label, label.error {
  color: #c60f13;
}

/* line 52, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.error small, small.error {
  display: block;
  padding: 6px 4px;
  margin-top: -13px;
  margin-bottom: 12px;
  background: #c60f13;
  color: #fff;
  font-size: 12px;
  font-weight: bold;
  -moz-border-radius-bottomleft: 2px;
  -webkit-border-bottom-left-radius: 2px;
  border-bottom-left-radius: 2px;
  -moz-border-radius-bottomright: 2px;
  -webkit-border-bottom-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

/* Custom Forms ---------------------- */
/* line 55, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom {
  /* Custom input, disabled */
}
/* line 57, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom span.custom {
  display: inline-block;
  width: 16px;
  height: 16px;
  position: relative;
  top: 2px;
  border: solid 1px #cccccc;
  background: white;
}
/* line 59, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom span.custom.radio {
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  -ms-border-radius: 100px;
  -o-border-radius: 100px;
  border-radius: 100px;
}
/* line 61, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom span.custom.checkbox:before {
  content: "";
  display: block;
  line-height: 0.8;
  height: 14px;
  width: 14px;
  text-align: center;
  position: absolute;
  top: 0;
  left: 0;
  font-size: 14px;
  color: #fff;
}
/* line 64, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom span.custom.radio.checked:before {
  content: "";
  display: block;
  width: 8px;
  height: 8px;
  -webkit-border-radius: 100px;
  -moz-border-radius: 100px;
  -ms-border-radius: 100px;
  -o-border-radius: 100px;
  border-radius: 100px;
  background: #222222;
  position: relative;
  top: 3px;
  left: 3px;
}
/* line 67, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom span.custom.checkbox.checked:before {
  content: "\00d7";
  color: #222222;
}
/* line 70, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown {
  display: block;
  position: relative;
  width: auto;
  height: 28px;
  margin-bottom: 9px;
  margin-top: 2px;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown ul {
  overflow-y: auto;
  max-height: 200px;
}
/* line 73, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown a.current {
  display: block;
  width: auto;
  line-height: 26px;
  min-height: 28px;
  padding: 0;
  padding-left: 6px;
  padding-right: 38px;
  border: solid 1px #dddddd;
  color: #141414;
  background-color: white;
  white-space: nowrap;
}
/* line 74, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown a.selector {
  position: absolute;
  width: 27px;
  height: 28px;
  display: block;
  right: 0;
  top: 0;
  border: solid 1px #dddddd;
}
/* line 75, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown a.selector:after {
  content: "";
  display: block;
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 5px;
  border-color: #aaaaaa transparent transparent transparent;
  position: absolute;
  left: 50%;
  top: 50%;
  margin-top: -2px;
  margin-left: -5px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown:hover a.selector:after, form.custom div.custom.dropdown.open a.selector:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 5px;
  border-color: #222222 transparent transparent transparent;
}
/* line 81, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown.open ul {
  display: block;
  z-index: 10;
}
/* line 83, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown.small {
  width: 134px !important;
}
/* line 84, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown.medium {
  width: 254px !important;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown.large {
  width: 434px !important;
}
/* line 86, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown.expand {
  width: 100% !important;
}
/* line 88, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown.open.small ul {
  width: 134px !important;
}
/* line 89, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown.open.medium ul {
  width: 254px !important;
}
/* line 90, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown.open.large ul {
  width: 434px !important;
}
/* line 91, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown.open.expand ul {
  width: 100% !important;
}
/* line 94, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown ul {
  position: absolute;
  width: auto;
  display: none;
  margin: 0;
  left: 0;
  top: 27px;
  margin: 0;
  padding: 0;
  background: white;
  background: rgba(255, 255, 255, 0.95);
  border: solid 1px #cccccc;
}
/* line 96, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown ul li {
  color: #555555;
  font-size: 13px;
  cursor: pointer;
  padding: 3px;
  padding-left: 6px;
  padding-right: 38px;
  min-height: 18px;
  line-height: 18px;
  margin: 0;
  white-space: nowrap;
  list-style: none;
}
/* line 97, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown ul li.selected {
  background: #cdebf5;
  color: black;
}
/* line 98, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown ul li.selected:after {
  content: "\2013";
  position: absolute;
  right: 10px;
}
/* line 100, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown ul li:hover {
  background-color: #cdebf5;
  color: black;
}
/* line 101, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown ul li:hover:after {
  content: "\2013";
  position: absolute;
  right: 10px;
  color: #a3dbec;
}
/* line 103, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown ul li.selected:hover {
  background: #cdebf5;
  cursor: default;
  color: black;
}
/* line 104, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown ul li.selected:hover:after {
  color: black;
}
/* line 106, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom div.custom.dropdown ul.show {
  display: block;
}
/* line 110, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
form.custom .custom.disabled {
  background-color: #dddddd;
}

/* Correct FF custom dropdown height */
@-moz-document url-prefix() {
  /* line 115, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
  form.custom div.custom.dropdown a.selector {
    height: 28px;
  }
}

/* line 117, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/common/_forms.scss */
.lt-ie9 form.custom div.custom.dropdown a.selector {
  height: 28px;
}

/* Normal Buttons ---------------------- */
/* line 3, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button {
  width: auto;
  background: #fd9c00;
  border: 1px solid #b16d00;
  -webkit-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.5) inset;
  -moz-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.5) inset;
  box-shadow: 0 1px 0 rgba(255, 255, 255, 0.5) inset;
  color: white;
  cursor: pointer;
  display: inline-block;
  font-family: inherit;
  font-size: 14px;
  font-weight: bold;
  line-height: 1;
  margin: 0;
  padding: 10px 20px 11px;
  position: relative;
  text-align: center;
  text-decoration: none;
  -webkit-transition: background-color 0.15s ease-in-out;
  -moz-transition: background-color 0.15s ease-in-out;
  -o-transition: background-color 0.15s ease-in-out;
  transition: background-color 0.15s ease-in-out;
  /* Hovers */
  /* Sizes */
  /* Colors */
  /* Radii */
  /* Layout */
  /* Disabled ---------- */
}
/* line 6, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button:hover, .button:focus {
  color: white;
  background-color: #ca7d00;
}
/* line 7, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button:active {
  -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.2) inset;
  -moz-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.2) inset;
  box-shadow: 0 1px 0 rgba(0, 0, 0, 0.2) inset;
}
/* line 10, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.large {
  font-size: 17px;
  padding: 15px 30px 16px;
}
/* line 11, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.medium {
  font-size: 14px;
}
/* line 12, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.small {
  font-size: 11px;
  padding: 7px 14px 8px;
}
/* line 13, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.tiny {
  font-size: 10px;
  padding: 5px 10px 6px;
}
/* line 14, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.expand {
  width: 100%;
  text-align: center;
}
/* line 17, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.primary {
  background-color: #fd9c00;
  border: 1px solid #b16d00;
}
/* line 18, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.primary:hover, .button.primary:focus {
  background-color: #ca7d00;
}
/* line 20, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.success {
  background-color: #5da423;
  border: 1px solid #396516;
}
/* line 21, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.success:hover, .button.success:focus {
  background-color: #457a1a;
}
/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.alert {
  background-color: #c60f13;
  border: 1px solid #7f0a0c;
}
/* line 24, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.alert:hover, .button.alert:focus {
  background-color: #970b0e;
}
/* line 26, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.secondary {
  background-color: #e9e9e9;
  color: #1d1d1d;
  border: 1px solid #c3c3c3;
}
/* line 27, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.secondary:hover, .button.secondary:focus {
  background-color: #d0d0d0;
}
/* line 31, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.radius {
  -webkit-border-radius: 7px;
  -moz-border-radius: 7px;
  -ms-border-radius: 7px;
  -o-border-radius: 7px;
  border-radius: 7px;
}
/* line 32, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.round {
  -webkit-border-radius: 1000px;
  -moz-border-radius: 1000px;
  -ms-border-radius: 1000px;
  -o-border-radius: 1000px;
  border-radius: 1000px;
}
/* line 35, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.full-width {
  width: 100%;
  text-align: center;
  padding-left: 0px !important;
  padding-right: 0px !important;
}
/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.left-align {
  text-align: left;
  text-indent: 12px;
}
/* line 39, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.disabled, .button[disabled] {
  opacity: 0.6;
  cursor: default;
  background: #fd9c00;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
/* line 40, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.disabled:hover, .button[disabled]:hover {
  background: #fd9c00;
}
/* line 42, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.disabled.success, .button[disabled].success {
  background-color: #5da423;
}
/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.disabled.success:hover, .button.disabled.success:focus, .button[disabled].success:hover, .button[disabled].success:focus {
  background-color: #5da423;
  outline: none;
}
/* line 45, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.disabled.alert, .button[disabled].alert {
  background-color: #c60f13;
}
/* line 46, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.disabled.alert:hover, .button.disabled.alert:focus, .button[disabled].alert:hover, .button[disabled].alert:focus {
  background-color: #c60f13;
  outline: none;
}
/* line 48, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.disabled.secondary, .button[disabled].secondary {
  background-color: #e9e9e9;
}
/* line 49, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.disabled.secondary:hover, .button.disabled.secondary:focus, .button[disabled].secondary:hover, .button[disabled].secondary:focus {
  background-color: #e9e9e9;
  outline: none;
}

/* Don't use native buttons on iOS */
/* line 55, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
input[type=submit].button, button.button {
  -webkit-appearance: none;
}

/* Correct FF button padding */
@-moz-document url-prefix() {
  /* line 59, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
  button::-moz-focus-inner, input[type="reset"]::-moz-focus-inner, input[type="button"]::-moz-focus-inner, input[type="submit"]::-moz-focus-inner, input[type="file"] > input[type="button"]::-moz-focus-inner {
    border: none;
    padding: 0;
  }

  /* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
  input[type="submit"].tiny.button {
    padding: 3px 10px 4px;
  }

  /* line 61, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
  input[type="submit"].small.button {
    padding: 5px 14px 6px;
  }

  /* line 62, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
  input[type="submit"].button, input[type=submit].medium.button {
    padding: 8px 20px 9px;
  }

  /* line 63, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
  input[type="submit"].large.button {
    padding: 13px 30px 14px;
  }
}

/* Buttons with Dropdowns ---------------------- */
/* line 68, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown {
  position: relative;
  padding-right: 44px;
  /* Sizes */
  /* Triangles */
  /* Flyout List */
  /* Split Dropdown Buttons */
}
/* line 71, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.large {
  padding-right: 60px;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.small {
  padding-right: 28px;
}
/* line 73, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.tiny {
  padding-right: 20px;
}
/* line 76, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 6px;
  border-color: white transparent transparent transparent;
  position: absolute;
  top: 50%;
  right: 20px;
  margin-top: -2px;
}
/* line 77, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.large:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 7px;
  border-color: white transparent transparent transparent;
  margin-top: -3px;
  right: 30px;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.small:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 5px;
  border-color: white transparent transparent transparent;
  margin-top: -2px;
  right: 14px;
}
/* line 79, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.tiny:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 4px;
  border-color: white transparent transparent transparent;
  margin-top: -1px;
  right: 10px;
}
/* line 82, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown > ul {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  display: none;
  position: absolute;
  left: -1px;
  background: #fff;
  background: rgba(255, 255, 255, 0.95);
  list-style: none;
  margin: 0;
  padding: 0;
  border: 1px solid #cccccc;
  border-top: none;
  min-width: 100%;
  z-index: 40;
}
/* line 84, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown > ul li {
  width: 100%;
  cursor: pointer;
  padding: 0;
  min-height: 18px;
  line-height: 18px;
  margin: 0;
  white-space: nowrap;
  list-style: none;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown > ul li a, .button.dropdown > ul li button {
  display: block;
  color: #555;
  font-size: 13px;
  font-weight: normal;
  padding: 6px 14px;
  text-align: left;
}
/* line 86, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown > ul li button {
  width: 100%;
  border: inherit;
  background: inherit;
  font-family: inherit;
  margin: inherit;
  -webkit-font-smoothing: antialiased;
}
/* line 87, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown > ul li:hover, .button.dropdown > ul li:focus {
  background-color: #fff4e3;
  color: #222;
}
/* line 88, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown > ul li.divider {
  min-height: 0;
  padding: 0;
  height: 1px;
  margin: 4px 0;
  background: #ededed;
}
/* line 92, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.up > ul {
  border-top: 1px solid #cccccc;
  border-bottom: none;
}
/* line 94, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown ul.no-hover.show-dropdown {
  display: block !important;
}
/* line 96, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown:hover > ul.no-hover {
  display: none;
}
/* line 102, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split {
  padding: 0;
  position: relative;
  /* Sizes */
  /* Triangle Spans */
  /* Colors */
}
/* line 104, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split:after {
  display: none;
}
/* line 105, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split:hover, .button.dropdown.split:focus {
  background-color: #fd9c00;
}
/* line 106, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.alert:hover, .button.dropdown.split.alert:focus {
  background-color: #c60f13;
}
/* line 107, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.success:hover, .button.dropdown.split.success:focus {
  background-color: #5da423;
}
/* line 108, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.secondary:hover, .button.dropdown.split.secondary:focus {
  background-color: #e9e9e9;
}
/* line 111, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split > a {
  color: white;
  display: block;
  padding: 10px 50px 11px 20px;
  padding-left: 20px;
  padding-right: 50px;
  -webkit-transition: background-color 0.15s ease-in-out;
  -moz-transition: background-color 0.15s ease-in-out;
  -o-transition: background-color 0.15s ease-in-out;
  transition: background-color 0.15s ease-in-out;
}
/* line 112, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split > a:hover, .button.dropdown.split > a:focus {
  background-color: #ca7d00;
  -webkit-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.5) inset;
  -moz-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.5) inset;
  box-shadow: 0 1px 0 rgba(255, 255, 255, 0.5) inset;
}
/* line 114, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.large > a {
  padding: 15px 75px 16px 30px;
  padding-left: 30px;
  padding-right: 75px;
}
/* line 115, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.small > a {
  padding: 7px 35px 8px 14px;
  padding-left: 14px;
  padding-right: 35px;
}
/* line 116, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.tiny > a {
  padding: 5px 25px 6px 10px;
  padding-left: 10px;
  padding-right: 25px;
}
/* line 119, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split > span {
  background-color: #fd9c00;
  position: absolute;
  right: 0;
  top: 0;
  height: 100%;
  width: 30px;
  border-left: 1px solid #b16d00;
  -webkit-box-shadow: 1px 1px 0 rgba(255, 255, 255, 0.5) inset;
  -moz-box-shadow: 1px 1px 0 rgba(255, 255, 255, 0.5) inset;
  box-shadow: 1px 1px 0 rgba(255, 255, 255, 0.5) inset;
  -webkit-transition: background-color 0.15s ease-in-out;
  -moz-transition: background-color 0.15s ease-in-out;
  -o-transition: background-color 0.15s ease-in-out;
  transition: background-color 0.15s ease-in-out;
}
/* line 120, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split > span:hover, .button.dropdown.split > span:focus {
  background-color: #ca7d00;
}
/* line 121, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split > span:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 6px;
  border-color: white transparent transparent transparent;
  position: absolute;
  top: 50%;
  left: 50%;
  margin-left: -6px;
  margin-top: -2px;
}
/* line 123, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.secondary > span:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 6px;
  border-color: #1d1d1d transparent transparent transparent;
}
/* line 125, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.large span {
  width: 45px;
}
/* line 126, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.small span {
  width: 21px;
}
/* line 127, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.tiny span {
  width: 15px;
}
/* line 129, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.large span:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 7px;
  border-color: white transparent transparent transparent;
  margin-top: -3px;
  margin-left: -7px;
}
/* line 130, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.small span:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 4px;
  border-color: white transparent transparent transparent;
  margin-top: -1px;
  margin-left: -4px;
}
/* line 131, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.tiny span:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 3px;
  border-color: white transparent transparent transparent;
  margin-top: -1px;
  margin-left: -3px;
}
/* line 134, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.alert > span {
  background-color: #c60f13;
  border-left-color: #7f0a0c;
}
/* line 135, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.success > span {
  background-color: #5da423;
  border-left-color: #396516;
}
/* line 136, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.secondary > span {
  background-color: #e9e9e9;
  border-left-color: #c3c3c3;
}
/* line 137, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.secondary > a {
  color: #1d1d1d;
}
/* line 139, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.alert > a:hover, .button.dropdown.split.alert > span:hover, .button.dropdown.split.alert > a:focus, .button.dropdown.split.alert > span:focus {
  background-color: #970b0e;
}
/* line 140, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.success > a:hover, .button.dropdown.split.success > span:hover, .button.dropdown.split.success > a:focus, .button.dropdown.split.success > span:focus {
  background-color: #457a1a;
}
/* line 141, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
.button.dropdown.split.secondary > a:hover, .button.dropdown.split.secondary > span:hover, .button.dropdown.split.secondary > a:focus, .button.dropdown.split.secondary > span:focus {
  background-color: #d0d0d0;
}

/* Button Groups ---------------------- */
/* line 147, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group {
  list-style: none;
  padding: 0;
  margin: 0 0 12px;
  *zoom: 1;
}
/* line 4, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
ul.button-group:before, ul.button-group:after {
  content: " ";
  display: table;
}
/* line 5, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
ul.button-group:after {
  clear: both;
}
/* line 149, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group li {
  padding: 0;
  margin: 0 0 0 -1px;
  float: left;
}
/* line 150, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group li:first-child {
  margin-left: 0;
}
/* line 154, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group.radius li .button, ul.button-group.radius li .button.radius, ul.button-group.radius li .button-rounded {
  -webkit-border-radius: 0px;
  -moz-border-radius: 0px;
  -ms-border-radius: 0px;
  -o-border-radius: 0px;
  border-radius: 0px;
}
/* line 156, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group.radius li:first-child .button, ul.button-group.radius li:first-child .button.radius {
  -moz-border-radius-topleft: 7px;
  -webkit-border-top-left-radius: 7px;
  border-top-left-radius: 7px;
  -moz-border-radius-bottomleft: 7px;
  -webkit-border-bottom-left-radius: 7px;
  border-bottom-left-radius: 7px;
}
/* line 157, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group.radius li:first-child .button.rounded {
  -moz-border-radius-topleft: 1000px;
  -webkit-border-top-left-radius: 1000px;
  border-top-left-radius: 1000px;
  -moz-border-radius-bottomleft: 1000px;
  -webkit-border-bottom-left-radius: 1000px;
  border-bottom-left-radius: 1000px;
}
/* line 160, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group.radius li:last-child .button, ul.button-group.radius li:last-child .button.radius {
  -moz-border-radius-topright: 7px;
  -webkit-border-top-right-radius: 7px;
  border-top-right-radius: 7px;
  -moz-border-radius-bottomright: 7px;
  -webkit-border-bottom-right-radius: 7px;
  border-bottom-right-radius: 7px;
}
/* line 161, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group.radius li:last-child .button.rounded {
  -moz-border-radius-topright: 1000px;
  -webkit-border-top-right-radius: 1000px;
  border-top-right-radius: 1000px;
  -moz-border-radius-bottomright: 1000px;
  -webkit-border-bottom-right-radius: 1000px;
  border-bottom-right-radius: 1000px;
}
/* line 166, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group.even .button {
  width: 100%;
}
/* line 167, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group.even.two-up li {
  width: 50%;
}
/* line 168, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group.even.three-up li {
  width: 33.3%;
}
/* line 169, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group.even.three-up li:first-child {
  width: 33.4%;
}
/* line 170, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group.even.four-up li {
  width: 25%;
}
/* line 171, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
ul.button-group.even.five-up li {
  width: 20%;
}

/* line 175, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
div.button-bar {
  overflow: hidden;
}
/* line 176, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
div.button-bar ul.button-group {
  float: left;
  margin-right: 8px;
}
/* line 177, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_buttons.scss */
div.button-bar ul.button-group:last-child {
  margin-left: 0;
}

/* Tabs ---------------------- */
/* line 3, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs {
  list-style: none;
  border-bottom: solid 1px #e6e6e6;
  display: block;
  height: 40px;
  padding: 0;
  margin-bottom: 20px;
}
/* line 4, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.contained {
  margin-bottom: 0;
  margin-left: 0;
}
/* line 6, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs dt, .tabs li.section-title {
  color: #b3b3b3;
  cursor: default;
  display: block;
  float: left;
  font-size: 12px;
  height: 40px;
  line-height: 40px;
  padding: 0;
  padding-right: 9px;
  padding-left: 20px;
  font-weight: normal;
  width: auto;
  text-transform: uppercase;
}
/* line 7, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs dt:first-child, .tabs li.section-title:first-child {
  padding: 0;
  padding-right: 9px;
}
/* line 10, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs dd, .tabs li {
  display: block;
  float: left;
  padding: 0;
  margin: 0;
}
/* line 11, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs dd a, .tabs li a {
  color: #6f6f6f;
  display: block;
  font-size: 14px;
  height: 40px;
  line-height: 40px;
  padding: 0px 23.8px;
}
/* line 12, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs dd a:focus, .tabs li a:focus {
  font-weight: bold;
  color: #fd9c00;
}
/* line 14, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs dd.active, .tabs li.active {
  border-top: 3px solid #fd9c00;
  margin-top: -3px;
}
/* line 15, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs dd.active a, .tabs li.active a {
  cursor: default;
  color: #3c3c3c;
  background: #fff;
  border-left: 1px solid #e6e6e6;
  border-right: 1px solid #e6e6e6;
  font-weight: bold;
}
/* line 17, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs dd:first-child, .tabs li:first-child {
  margin-left: 0;
}
/* line 20, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.vertical {
  height: auto;
  border-bottom: 1px solid #e6e6e6;
}
/* line 21, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.vertical dt, .tabs.vertical dd, .tabs.vertical li {
  float: none;
  height: auto;
}
/* line 23, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.vertical dd, .tabs.vertical li {
  border-left: 3px solid #cccccc;
}
/* line 24, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.vertical dd a, .tabs.vertical li a {
  background: #f2f2f2;
  border: none;
  border: 1px solid #e6e6e6;
  border-width: 1px 1px 0 0;
  color: #555;
  display: block;
  font-size: 14px;
  height: auto;
  line-height: 1;
  padding: 15px 20px;
  -webkit-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.5) inset;
  -moz-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.5) inset;
  box-shadow: 0 1px 0 rgba(255, 255, 255, 0.5) inset;
}
/* line 26, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.vertical dd.active, .tabs.vertical li.active {
  margin-top: 0;
  border-top: 1px solid #4d4d4d;
  border-left: 4px solid #1a1a1a;
}
/* line 27, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.vertical dd.active a, .tabs.vertical li.active a {
  background: #4d4d4d;
  border: none;
  color: #fff;
  height: auto;
  margin: 0;
  position: static;
  top: 0;
  -webkit-box-shadow: 0 0 0;
  -moz-box-shadow: 0 0 0;
  box-shadow: 0 0 0;
}
/* line 29, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.vertical dd:first-child a.active, .tabs.vertical li:first-child a.active {
  margin: 0;
}
/* line 33, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.pill {
  border-bottom: none;
  margin-bottom: 10px;
}
/* line 34, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.pill dd, .tabs.pill li {
  margin-right: 10px;
}
/* line 35, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.pill dd:last-child, .tabs.pill li:last-child {
  margin-right: 0;
}
/* line 36, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.pill dd a, .tabs.pill li a {
  -webkit-border-radius: 1000px;
  -moz-border-radius: 1000px;
  -ms-border-radius: 1000px;
  -o-border-radius: 1000px;
  border-radius: 1000px;
  background: #e6e6e6;
  height: 26px;
  line-height: 26px;
  color: #666;
}
/* line 38, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.pill dd.active, .tabs.pill li.active {
  border: none;
  margin-top: 0;
}
/* line 39, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.pill dd.active a, .tabs.pill li.active a {
  background-color: #fd9c00;
  border: none;
  color: #fff;
}
/* line 42, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.pill.contained {
  border-bottom: solid 1px #eee;
  margin-bottom: 0;
}
/* line 44, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.pill.two-up dd, .tabs.pill.two-up li, .tabs.pill.three-up dd, .tabs.pill.three-up li, .tabs.pill.four-up dd, .tabs.pill.four-up li, .tabs.pill.five-up dd, .tabs.pill.five-up li {
  margin-right: 0;
}
/* line 49, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.two-up dt a, .tabs.two-up dd a, .tabs.two-up li a, .tabs.three-up dt a, .tabs.three-up dd a, .tabs.three-up li a, .tabs.four-up dt a, .tabs.four-up dd a, .tabs.four-up li a, .tabs.five-up dt a, .tabs.five-up dd a, .tabs.five-up li a {
  padding: 0 17px;
  text-align: center;
  overflow: hidden;
}
/* line 51, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.two-up dt, .tabs.two-up dd, .tabs.two-up li {
  width: 50%;
}
/* line 52, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.three-up dt, .tabs.three-up dd, .tabs.three-up li {
  width: 33.33%;
}
/* line 53, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.four-up dt, .tabs.four-up dd, .tabs.four-up li {
  width: 25%;
}
/* line 54, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.tabs.five-up dt, .tabs.five-up dd, .tabs.five-up li {
  width: 20%;
}

/* line 57, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
ul.tabs-content {
  display: block;
  margin: 0 0 20px;
  padding: 0;
}
/* line 58, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
ul.tabs-content > li {
  display: none;
}
/* line 59, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
ul.tabs-content > li.active {
  display: block;
}
/* line 61, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
ul.tabs-content.contained {
  padding: 0;
}
/* line 62, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
ul.tabs-content.contained > li {
  border: solid 0 #e6e6e6;
  border-width: 0 1px 1px 1px;
  padding: 20px;
}
/* line 63, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
ul.tabs-content.contained.vertical > li {
  border-width: 1px 1px 1px 1px;
}

/* line 67, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_tabs.scss */
.no-js ul.tabs-content > li {
  display: block;
}

/* Table of Contents

:: Visibility
:: Alerts
:: Labels
:: Tooltips
:: Panels
:: Accordion
:: Side Nav
:: Sub Nav
:: Pagination
:: Breadcrumbs
:: Lists
:: Inline/Link Lists
:: Keystroke Chars
:: Image Thumbnails
:: Video
:: Tables
:: Microformats
:: Progress Bars
:: Pricing Tables

*/
/* Alerts ---------------------- */
/* line 27, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.alert-box {
  display: block;
  padding: 6px 7px 7px;
  font-weight: bold;
  font-size: 14px;
  color: white;
  background-color: #fd9c00;
  border: 1px solid rgba(0, 0, 0, 0.1);
  margin-bottom: 12px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.3);
  position: relative;
}
/* line 29, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.alert-box.success {
  background-color: #5da423;
  color: #fff;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.3);
}
/* line 30, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.alert-box.alert {
  background-color: #c60f13;
  color: #fff;
  text-shadow: 0 -1px rgba(0, 0, 0, 0.3);
}
/* line 31, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.alert-box.secondary {
  background-color: #e9e9e9;
  color: #505050;
  text-shadow: 0 1px rgba(255, 255, 255, 0.3);
}
/* line 33, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.alert-box a.close {
  color: #333;
  position: absolute;
  right: 4px;
  top: -1px;
  font-size: 17px;
  opacity: 0.2;
  padding: 4px;
}
/* line 34, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.alert-box a.close:hover, div.alert-box a.close:focus {
  opacity: 0.4;
}

/* Labels ---------------------- */
/* line 41, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.label {
  padding: 1px 4px 2px;
  font-size: 12px;
  font-weight: bold;
  text-align: center;
  text-decoration: none;
  line-height: 1;
  white-space: nowrap;
  display: inline;
  position: relative;
  bottom: 1px;
  color: #fff;
  background: #fd9c00;
}
/* line 43, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.label.radius {
  -webkit-border-radius: 7px;
  -moz-border-radius: 7px;
  -ms-border-radius: 7px;
  -o-border-radius: 7px;
  border-radius: 7px;
}
/* line 44, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.label.round {
  padding: 1px 7px 2px;
  -webkit-border-radius: 1000px;
  -moz-border-radius: 1000px;
  -ms-border-radius: 1000px;
  -o-border-radius: 1000px;
  border-radius: 1000px;
}
/* line 46, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.label.alert {
  background-color: #c60f13;
}
/* line 47, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.label.success {
  background-color: #5da423;
}
/* line 48, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.label.secondary {
  background-color: #e9e9e9;
  color: #505050;
}

/* Tooltips ---------------------- */
/* line 54, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.has-tip {
  border-bottom: dotted 1px #cccccc;
  cursor: help;
  font-weight: bold;
  color: #333333;
}
/* line 56, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.has-tip:hover, .has-tip:focus {
  border-bottom: dotted 1px #975d00;
  color: #fd9c00;
}
/* line 57, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.has-tip.tip-left, .has-tip.tip-right {
  float: none !important;
}

/* line 61, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.tooltip {
  display: none;
  background: black;
  background: rgba(0, 0, 0, 0.85);
  position: absolute;
  color: white;
  font-weight: bold;
  font-size: 12px;
  padding: 5px;
  z-index: 999;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  -ms-border-radius: 4px;
  -o-border-radius: 4px;
  border-radius: 4px;
  line-height: normal;
}
/* line 63, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.tooltip > .nub {
  display: block;
  width: 0;
  height: 0;
  border: solid 5px;
  border-color: transparent transparent black transparent;
  border-color: transparent transparent rgba(0, 0, 0, 0.85) transparent;
  position: absolute;
  top: -10px;
  left: 10px;
}
/* line 64, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.tooltip.tip-override > .nub {
  border-color: transparent transparent black transparent !important;
  border-color: transparent transparent rgba(0, 0, 0, 0.85) transparent !important;
  top: -10px !important;
}
/* line 65, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.tooltip.tip-top > .nub, .tooltip.tip-centered-top > .nub {
  border-color: black transparent transparent transparent;
  border-color: rgba(0, 0, 0, 0.85) transparent transparent transparent;
  top: auto;
  bottom: -10px;
}
/* line 67, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.tooltip.tip-left, .tooltip.tip-right {
  float: none !important;
}
/* line 69, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.tooltip.tip-left > .nub {
  border-color: transparent transparent transparent black;
  border-color: transparent transparent transparent rgba(0, 0, 0, 0.85);
  right: -10px;
  left: auto;
}
/* line 70, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.tooltip.tip-right > .nub {
  border-color: transparent black transparent transparent;
  border-color: transparent rgba(0, 0, 0, 0.85) transparent transparent;
  right: auto;
  left: -10px;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.tooltip.noradius {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  -o-border-radius: 0;
  border-radius: 0;
}
/* line 73, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.tooltip.opened {
  color: #fd9c00 !important;
  border-bottom: dotted 1px #975d00 !important;
}

/* line 77, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.tap-to-close {
  display: block;
  font-size: 10px;
  font-size: 1rem;
  color: #888888;
  font-weight: normal;
}

/* Panels ---------------------- */
/* line 81, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.panel {
  background: #f2f2f2;
  border: solid 1px #e6e6e6;
  margin: 0 0 22px 0;
  padding: 20px;
}
/* line 83, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.panel > :first-child {
  margin-top: 0;
}
/* line 84, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.panel > :last-child {
  margin-bottom: 0;
}
/* line 86, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.panel.callout {
  background: #fd9c00;
  color: #fff;
  border-color: #ca7d00;
  -webkit-box-shadow: inset 0px 1px 0px rgba(255, 255, 255, 0.5);
  -moz-box-shadow: inset 0px 1px 0px rgba(255, 255, 255, 0.5);
  box-shadow: inset 0px 1px 0px rgba(255, 255, 255, 0.5);
}
/* line 87, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.panel.callout a {
  color: #fff;
}
/* line 88, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.panel.callout .button {
  background: white;
  border: none;
  color: #fd9c00;
  text-shadow: none;
}
/* line 90, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.panel.callout .button:hover, .panel.callout .button:focus {
  background: rgba(255, 255, 255, 0.8);
}
/* line 94, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.panel.radius {
  -webkit-border-radius: 7px;
  -moz-border-radius: 7px;
  -ms-border-radius: 7px;
  -o-border-radius: 7px;
  border-radius: 7px;
}

/* Accordion ---------------------- */
/* line 100, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.accordion {
  margin: 0 0 22px 0;
  border-bottom: 1px solid #e9e9e9;
}
/* line 102, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.accordion > li {
  list-style: none;
  margin: 0;
  padding: 0;
  border-top: 1px solid #e9e9e9;
}
/* line 104, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.accordion > li > div.title {
  cursor: pointer;
  background: #f6f6f6;
  padding: 15px;
  margin: 0;
  position: relative;
  border-left: 1px solid #e9e9e9;
  border-right: 1px solid #e9e9e9;
  -webkit-transition: 0.15s background linear;
  -moz-transition: 0.15s background linear;
  -o-transition: 0.15s background linear;
  transition: 0.15s background linear;
}
/* line 106, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.accordion > li > div.title h1, ul.accordion > li > div.title h2, ul.accordion > li > div.title h3, ul.accordion > li > div.title h4, ul.accordion > li > div.title h5 {
  margin: 0;
}
/* line 107, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.accordion > li > div.title:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 6px;
  border-color: transparent #9d9d9d transparent transparent;
  position: absolute;
  right: 15px;
  top: 21px;
}
/* line 110, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.accordion > li .content {
  display: none;
  padding: 15px;
}
/* line 112, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.accordion > li.active {
  border-top: 3px solid #fd9c00;
}
/* line 114, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.accordion > li.active .title {
  background: white;
  padding-top: 13px;
}
/* line 116, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.accordion > li.active .title:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 6px;
  border-color: #9d9d9d transparent transparent transparent;
}
/* line 118, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.accordion > li.active .content {
  background: white;
  display: block;
  border-left: 1px solid #e9e9e9;
  border-right: 1px solid #e9e9e9;
}

/* Side Nav ---------------------- */
/* line 127, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.side-nav {
  display: block;
  list-style: none;
  margin: 0;
  padding: 17px 0;
}
/* line 129, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.side-nav li {
  display: block;
  list-style: none;
  margin: 0 0 7px 0;
}
/* line 131, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.side-nav li a {
  display: block;
}
/* line 132, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.side-nav li.active a {
  color: #4d4d4d;
  font-weight: bold;
}
/* line 133, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.side-nav li.divider {
  border-top: 1px solid #e6e6e6;
  height: 0;
  padding: 0;
}

/* Sub Navs http://www.zurb.com/article/292/how-to-create-simple-and-effective-sub-na ---------------------- */
/* line 139, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
dl.sub-nav {
  display: block;
  width: auto;
  overflow: hidden;
  margin: -4px 0 18px;
  margin-right: 0;
  margin-left: -9px;
  padding-top: 4px;
}
/* line 141, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
dl.sub-nav dt, dl.sub-nav dd {
  float: left;
  display: inline;
  margin-left: 9px;
  margin-bottom: 10px;
}
/* line 142, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
dl.sub-nav dt {
  color: #999;
  font-weight: normal;
}
/* line 143, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
dl.sub-nav dd a {
  text-decoration: none;
  -webkit-border-radius: 1000px;
  -moz-border-radius: 1000px;
  -ms-border-radius: 1000px;
  -o-border-radius: 1000px;
  border-radius: 1000px;
}
/* line 144, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
dl.sub-nav dd.active a {
  font-weight: bold;
  background: #fd9c00;
  color: #fff;
  padding: 3px 9px;
  cursor: default;
}

/* Pagination ---------------------- */
/* line 150, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.pagination {
  display: block;
  height: 24px;
  margin-left: -5px;
}
/* line 152, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.pagination li {
  float: left;
  display: block;
  height: 24px;
  color: #999;
  font-size: 14px;
  margin-left: 5px;
}
/* line 154, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.pagination li a {
  display: block;
  padding: 1px 7px 1px;
  color: #555;
}
/* line 155, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.pagination li:hover a, ul.pagination li a:focus {
  background: #e6e6e6;
}
/* line 156, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.pagination li.unavailable a {
  cursor: default;
  color: #999;
}
/* line 157, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.pagination li.unavailable:hover a, ul.pagination li.unavailable a:focus {
  background: transparent;
}
/* line 158, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.pagination li.current a {
  background: #fd9c00;
  color: white;
  font-weight: bold;
  cursor: default;
}
/* line 159, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.pagination li.current a:hover, ul.pagination li.current a:focus {
  background: #fd9c00;
}

/* line 165, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.pagination-centered {
  text-align: center;
}
/* line 167, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.pagination-centered ul > li {
  float: none;
  display: inline-block;
}

/* Breadcrums ---------------------- */
/* line 172, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.breadcrumbs {
  display: block;
  background: #f6f6f6;
  padding: 6px 10px 7px;
  border: 1px solid #e9e9e9;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  -ms-border-radius: 2px;
  -o-border-radius: 2px;
  border-radius: 2px;
  overflow: hidden;
  margin-left: 0;
}
/* line 174, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.breadcrumbs li {
  margin: 0;
  padding: 0 12px 0 0;
  float: left;
  list-style: none;
}
/* line 176, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.breadcrumbs li a, ul.breadcrumbs li span {
  text-transform: uppercase;
  font-size: 11px;
  font-size: 1.1rem;
  padding-left: 12px;
}
/* line 177, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.breadcrumbs li:first-child a, ul.breadcrumbs li:first-child span {
  padding-left: 0;
}
/* line 180, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.breadcrumbs li:before {
  content: "/";
  color: #aaa;
}
/* line 181, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.breadcrumbs li:first-child:before {
  content: " ";
}
/* line 182, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.breadcrumbs li.current a {
  cursor: default;
  color: #333;
}
/* line 183, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.breadcrumbs li:hover a, ul.breadcrumbs li a:focus {
  text-decoration: underline;
}
/* line 184, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.breadcrumbs li.current:hover a, ul.breadcrumbs li.current a:focus {
  text-decoration: none;
}
/* line 186, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.breadcrumbs li.unavailable a {
  color: #999;
}
/* line 187, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.breadcrumbs li.unavailable:hover a, ul.breadcrumbs li.unavailable a:focus {
  text-decoration: none;
  color: #999;
  cursor: default;
}

/* Inline Link List */
/* line 193, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.inline-list, ul.link-list {
  margin: 0 0 17px -22px;
  padding: 0;
  list-style: none;
  overflow: hidden;
}
/* line 195, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.inline-list > li, ul.link-list > li {
  list-style: none;
  float: left;
  margin-left: 22px;
  display: block;
}
/* line 197, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.inline-list > li > *, ul.link-list > li > * {
  display: block;
}

/* Keytroke Characters ---------------------- */
/* line 203, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.keystroke, kbd {
  font-family: "Consolas", "Menlo", "Courier", monospace;
  font-size: 13px;
  padding: 2px 4px 0px;
  margin: 0;
  background: #ededed;
  border: solid 1px #dbdbdb;
  -webkit-border-radius: 7px;
  -moz-border-radius: 7px;
  -ms-border-radius: 7px;
  -o-border-radius: 7px;
  border-radius: 7px;
}

/* Image Thumbnails ---------------------- */
/* line 206, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.th {
  display: block;
}
/* line 207, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.th img {
  display: block;
  border: solid 4px #fff;
  -webkit-box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.2);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.2);
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  -webkit-transition-property: box-shadow;
  -moz-transition-property: box-shadow;
  -o-transition-property: box-shadow;
  transition-property: box-shadow;
  -webkit-transition-duration: 300ms;
  -moz-transition-duration: 300ms;
  -o-transition-duration: 300ms;
  transition-duration: 300ms;
}
/* line 209, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.th:hover img, .th:focus img {
  -webkit-box-shadow: 0 0 6px 1px rgba(253, 156, 0, 0.5);
  -moz-box-shadow: 0 0 6px 1px rgba(253, 156, 0, 0.5);
  box-shadow: 0 0 6px 1px rgba(253, 156, 0, 0.5);
}

/* Video - Mad props to http://www.alistapart.com/articles/creating-intrinsic-ratios-for-video/ ---------------------- */
/* line 215, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.flex-video {
  position: relative;
  padding-top: 25px;
  padding-bottom: 67.5%;
  height: 0;
  margin-bottom: 16px;
  overflow: hidden;
}
/* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.flex-video.widescreen {
  padding-bottom: 57.25%;
}
/* line 224, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.flex-video.vimeo {
  padding-top: 0;
}
/* line 226, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.flex-video iframe, .flex-video object, .flex-video embed, .flex-video video {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}

/* Tables ---------------------- */
/* line 232, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
table {
  background: #fff;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
  margin: 0 0 18px;
  border: 1px solid #ddd;
}

/* line 234, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
table thead, table tfoot {
  background: #f5f5f5;
}

/* line 239, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
table thead tr th,
table tfoot tr th,
table tbody tr td,
table tr td,
table tfoot tr td {
  display: table-cell;
  font-size: 14px;
  line-height: 18px;
  text-align: left;
}

/* line 241, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
table thead tr th,
table tfoot tr td {
  padding: 8px 10px 9px;
  font-size: 14px;
  font-weight: bold;
  color: #222;
}

/* line 242, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
table thead tr th:first-child, table tfoot tr td:first-child {
  border-left: none;
}

/* line 243, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
table thead tr th:last-child, table tfoot tr td:last-child {
  border-right: none;
}

/* line 246, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
table tbody tr.even,
table tbody tr.alt {
  background: #f9f9f9;
}

/* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
table tbody tr:nth-child(even) {
  background: #f9f9f9;
}

/* line 248, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
table tbody tr td {
  color: #333;
  padding: 9px 10px;
  vertical-align: top;
  border: none;
}

/* Microformats ---------------------- */
/* line 252, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.vcard {
  display: inline-block;
  margin: 0 0 12px 0;
  border: 1px solid #ddd;
  padding: 10px;
}
/* line 254, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.vcard li {
  margin: 0;
  display: block;
}
/* line 255, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
ul.vcard li.fn {
  font-weight: bold;
  font-size: 15px;
}

/* line 260, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
p.vevent span.summary {
  font-weight: bold;
}
/* line 261, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
p.vevent abbr {
  cursor: default;
  text-decoration: none;
  font-weight: bold;
  border: none;
  padding: 0 1px;
}

/* Progress Bar ---------------------- */
/* line 266, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.progress {
  padding: 2px;
  margin-bottom: 10px;
  border: 1px solid #cccccc;
  height: 25px;
  /* meter */
  /* border radii */
}
/* line 269, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.progress .meter {
  background: #fd9c00;
  height: 100%;
  display: block;
  width: 50%;
}
/* line 270, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.progress.secondary .meter {
  background: #e9e9e9;
}
/* line 271, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.progress.success .meter {
  background: #5da423;
}
/* line 272, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.progress.alert .meter {
  background: #c60f13;
}
/* line 275, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.progress.radius {
  -webkit-border-radius: 7px;
  -moz-border-radius: 7px;
  -ms-border-radius: 7px;
  -o-border-radius: 7px;
  border-radius: 7px;
}
/* line 276, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.progress.radius .meter {
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  -ms-border-radius: 2px;
  -o-border-radius: 2px;
  border-radius: 2px;
}
/* line 278, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.progress.round {
  -webkit-border-radius: 1000px;
  -moz-border-radius: 1000px;
  -ms-border-radius: 1000px;
  -o-border-radius: 1000px;
  border-radius: 1000px;
}
/* line 279, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
div.progress.round .meter {
  -webkit-border-radius: 1000px;
  -moz-border-radius: 1000px;
  -ms-border-radius: 1000px;
  -o-border-radius: 1000px;
  border-radius: 1000px;
}

/* Pricing Tables ---------------------- */
/* line 285, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.pricing-table {
  border: solid 1px #dddddd;
  margin-left: 0;
  margin-bottom: 20px;
}
/* line 286, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.pricing-table * {
  list-style: none;
  line-height: 1;
}
/* line 287, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.pricing-table .title {
  background-color: #dddddd;
  padding: 15px 20px;
  text-align: center;
  color: #333333;
  font-weight: bold;
  font-size: 16px;
}
/* line 288, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.pricing-table .price {
  background-color: #eeeeee;
  padding: 15px 20px;
  text-align: center;
  color: #333333;
  font-weight: normal;
  font-size: 20px;
}
/* line 289, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.pricing-table .description {
  background-color: white;
  padding: 15px;
  text-align: center;
  color: #777777;
  font-size: 12px;
  font-weight: normal;
  line-height: 1.4;
  border-bottom: dotted 1px #dddddd;
}
/* line 290, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.pricing-table .bullet-item {
  background-color: white;
  padding: 15px;
  text-align: center;
  color: #333333;
  font-size: 14px;
  font-weight: normal;
  border-bottom: dotted 1px #dddddd;
}
/* line 291, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_ui.scss */
.pricing-table .cta-button {
  background-color: whitesmoke;
  text-align: center;
  padding: 20px;
}

/*
  Foundation Top Bar

  Requires:
    -jquery.foundation.topbar.js

  Notes:
    - <nav class="top-bar"> can have .fixed added to make it stick to the top of viewport. Can add .contain-to-grid to top-bar to make it full width but content on grid.
    - <li class="name"> creates a branding area that can be linked to homepage
      - Can include text, image or both inside this <li>.
    - <li class="divider"> creates a divider between nav items, add margins for space
    - <li class="search"> Needs to hold a <form> which can use .row.collapse and pre/postfix buttons or default type="search"
*/
/* Element that controls breakpoint, no need to change this ever */
/* line 16, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar-js-breakpoint {
  width: 940px !important;
  visibility: hidden;
}

/* Wrapped around .top-bar to contain to grid width */
/* line 19, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.contain-to-grid {
  width: 100%;
  background: black;
}

/* Wrapped around .top-bar to make it fixed at the top */
/* line 22, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.fixed {
  width: 100%;
  left: 0;
  position: fixed;
  top: 0;
  z-index: 99;
}

/* Add .sticky class for using top bar as a sticky navigation when scrolling passed it. Add the class .sticky to a top bar using .contain-to-grid but leave off .fixed, javascript will take care of that */
/* line 25, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.sticky {
  float: left;
  overflow: hidden;
}
/* line 26, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.sticky.fixed {
  float: none;
}

/* <nav> */
/* line 30, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar {
  background: black;
  min-height: 105px;
  line-height: 105px;
  margin: 0 0 30px 0;
  padding: 0;
  width: 100%;
  position: relative;
  /* Contain width to .row width */
  /* First <ul> for branding, title, name, etc */
  /* topbar global <ul> styles */
}
/* line 33, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.contain-to-grid .top-bar {
  max-width: 1000px;
  margin: 0 auto;
}
/* line 38, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar > ul .name h1 {
  line-height: 105px;
  margin: 0;
}
/* line 39, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar > ul .name h1 a {
  font-weight: bold;
  padding: 0 52.5px;
  font-size: 36px !important;
}
/* line 41, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar > ul .name img {
  margin-top: -5px;
  vertical-align: middle;
}
/* line 44, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar.expanded {
  height: inherit;
}
/* line 47, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul {
  margin-left: 0;
  display: inline;
  height: 105px;
  line-height: 105px;
  list-style: none;
  /* Main Navigation links style */
  /* Left Side <ul> */
  /* Right Side <ul> */
}
/* line 50, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li {
  float: left;
  /* Dividers between navigation */
  /* Put a button in an <li> but give is a class */
  /* Put a search bar or text input in the bar */
  /* Put login bar in the top bar */
  /* Hide the triangle for breakpoint menu */
  /* li.has-dropdown */
}
/* line 51, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li a:not(.button) {
  color: white;
  display: block;
  font-size: 13px;
  font-weight: bold;
  height: 105px;
  line-height: 105px;
  padding: 0 35px;
}
/* line 53, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li:not(.name):hover, .top-bar ul > li:not(.name).active, .top-bar ul > li:not(.name):focus {
  background: black;
}
/* line 54, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li:not(.name):hover a, .top-bar ul > li:not(.name).active a, .top-bar ul > li:not(.name):focus a {
  color: #d9d9d9;
}
/* line 59, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.divider {
  background: black;
  -webkit-box-shadow: 1px 0 0 rgba(255, 255, 255, 0.1);
  -moz-box-shadow: 1px 0 0 rgba(255, 255, 255, 0.1);
  box-shadow: 1px 0 0 rgba(255, 255, 255, 0.1);
  height: 100%;
  margin-right: 1px;
  width: 1px;
}
/* line 63, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-button a.button {
  margin: 0 26.25px;
}
/* line 64, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-button:hover, .top-bar ul > li.has-button:focus {
  background: black;
}
/* line 65, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-button:hover a, .top-bar ul > li.has-button:focus a {
  color: #fff;
}
/* line 70, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.search {
  padding: 0 35px;
}
/* line 71, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.search form {
  display: inline-block;
  margin-bottom: 0;
  vertical-align: middle;
  width: 200px;
}
/* line 72, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.search form input[type=text] {
  -moz-border-radius-topright: 0;
  -webkit-border-top-right-radius: 0;
  border-top-right-radius: 0;
  -moz-border-radius-bottomright: 0;
  -webkit-border-bottom-right-radius: 0;
  border-bottom-right-radius: 0;
  float: left;
  font-size: 13px;
  margin-top: -1px;
  height: 52.5px;
  margin-bottom: 0;
  width: 130px;
}
/* line 74, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.search form input[type=text] + .button {
  border-left: none;
  -moz-border-radius-topleft: 0;
  -webkit-border-top-left-radius: 0;
  border-top-left-radius: 0;
  -moz-border-radius-bottomleft: 0;
  -webkit-border-bottom-left-radius: 0;
  border-bottom-left-radius: 0;
  float: left;
  font-size: 12px;
  margin-top: -1px;
  padding: 5px 12px 4px;
}
/* line 76, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.search form input[type=search] {
  font-size: 16px;
  margin-bottom: 0;
}
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.search:hover, .top-bar ul > li.search:focus {
  background: black;
}
/* line 82, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.login {
  padding: 0 35px;
}
/* line 83, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.login form {
  display: inline-block;
  margin-bottom: 0;
  vertical-align: middle;
  width: 300px;
}
/* line 84, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.login form input {
  float: left;
  width: auto;
  font-size: 13px;
  margin-top: -1px;
  height: 52.5px;
  margin-bottom: 0;
}
/* line 85, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.login form input[type=text] {
  -moz-border-radius-topright: 0;
  -webkit-border-top-right-radius: 0;
  border-top-right-radius: 0;
  -moz-border-radius-bottomright: 0;
  -webkit-border-bottom-right-radius: 0;
  border-bottom-right-radius: 0;
  width: 120px;
}
/* line 86, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.login form input[type=password] {
  margin-bottom: 0;
  -moz-border-radius-topleft: 0;
  -webkit-border-top-left-radius: 0;
  border-top-left-radius: 0;
  -moz-border-radius-bottomleft: 0;
  -webkit-border-bottom-left-radius: 0;
  border-bottom-left-radius: 0;
  width: 120px;
}
/* line 87, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.login form input[type=password] + .button {
  border-left: none;
  -moz-border-radius-topleft: 0;
  -webkit-border-top-left-radius: 0;
  border-top-left-radius: 0;
  -moz-border-radius-bottomleft: 0;
  -webkit-border-bottom-left-radius: 0;
  border-bottom-left-radius: 0;
  -moz-border-radius-topright: 2px;
  -webkit-border-top-right-radius: 2px;
  border-top-right-radius: 2px;
  -moz-border-radius-bottomright: 2px;
  -webkit-border-bottom-right-radius: 2px;
  border-bottom-right-radius: 2px;
  float: left;
  font-size: 12px;
  margin-top: -1px;
  padding: 5px 12px 4px;
  width: 60px;
}
/* line 90, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.login:hover, .top-bar ul > li.login:focus {
  background: black;
}
/* line 94, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.toggle-topbar {
  display: none;
}
/* line 97, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown {
  position: relative;
  /* Dropdown Level 2+ */
}
/* line 98, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown:hover > .dropdown, .top-bar ul > li.has-dropdown:focus > .dropdown {
  display: block;
  visibility: visible;
}
/* line 99, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown a {
  padding-right: 78.75px;
}
/* line 100, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown a:after {
  content: "";
  display: block;
  width: 0;
  height: 0;
  border: solid 5px;
  border-color: white transparent transparent transparent;
  margin-right: 35px;
  margin-top: -2.5px;
  position: absolute;
  right: 0;
  top: 50%;
}
/* line 102, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown {
  background: #222222;
  left: 0;
  margin: 0;
  padding: 21px 0 0 0;
  position: absolute;
  visibility: hidden;
  z-index: 99;
}
/* line 103, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li {
  background: #222222;
  line-height: 1;
  min-width: 100%;
  padding-bottom: 5px;
}
/* line 104, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li a {
  color: white;
  font-weight: normal;
  height: 100%;
  line-height: 1;
  padding: 5px 37px 5px 35px;
  white-space: nowrap;
}
/* line 105, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li a:after {
  border: none;
}
/* line 106, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li a:hover, .top-bar ul > li.has-dropdown .dropdown li a:focus {
  background: #3c3c3c;
}
/* line 108, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li label {
  color: #6f6f6f;
  font-size: 10px;
  font-weight: bold;
  margin: 0;
  padding-left: 35px;
  text-transform: uppercase;
}
/* line 109, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li.divider {
  border-top: solid 1px black;
  -webkit-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.1) inset;
  -moz-box-shadow: 0 1px 0 rgba(255, 255, 255, 0.1) inset;
  box-shadow: 0 1px 0 rgba(255, 255, 255, 0.1) inset;
  height: 10px;
  padding: 0;
  width: 100%;
}
/* line 110, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li:last-child {
  padding-bottom: 10px;
}
/* line 111, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li.active a {
  background: black;
}
/* line 117, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li.has-dropdown > a {
  padding-right: 30px;
}
/* line 118, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li.has-dropdown > a:after {
  border: none;
  content: "\00bb";
  right: 5px;
  top: 6px;
}
/* line 120, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li.has-dropdown .dropdown {
  position: absolute;
  left: 100%;
  top: 0;
}
/* line 122, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul > li.has-dropdown .dropdown li.has-dropdown:hover > .dropdown, .top-bar ul > li.has-dropdown .dropdown li.has-dropdown:focus > .dropdown {
  display: block;
}
/* line 129, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul.left {
  float: left;
  width: auto;
  margin-bottom: 0;
}
/* line 132, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul.right {
  float: right;
  width: auto;
  margin-bottom: 0;
  /* Dropdown Right Side Alignment */
}
/* line 134, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul.right .has-dropdown .dropdown {
  left: auto;
  right: 0px;
}
/* line 135, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar ul.right .has-dropdown .dropdown li.has-dropdown > .dropdown {
  right: 100%;
  left: auto;
  width: 100%;
}
/* line 140, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.top-bar .js-generated {
  display: none;
}

/* Firefox Fixes */
@-moz-document url-prefix() {
  /* line 145, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
  .top-bar ul li .button.small {
    padding-bottom: 6px;
  }

  /* line 146, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
  .top-bar ul li.search form input[type=search] {
    font-size: 14px;
    height: 22px;
    padding: 3px;
  }
}

/* IE8 Fixes */
/* line 150, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.lt-ie9 .top-bar ul li a {
  color: white;
  display: block;
  font-weight: bold;
  font-size: 13px;
  height: 105px;
  line-height: 105px;
  padding: 0 35px;
}
/* line 151, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.lt-ie9 .top-bar ul li a.button {
  height: auto;
  line-height: 30px;
  margin-top: 7px;
}
/* line 152, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.lt-ie9 .top-bar ul li a img {
  margin-top: -5px;
  vertical-align: middle;
}

/* line 158, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.lt-ie9 .top-bar section > ul > li a:hover, .lt-ie9 .top-bar section > ul > li a:focus {
  color: #cccccc;
}
/* line 160, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.lt-ie9 .top-bar section > ul > li:hover, .lt-ie9 .top-bar section > ul > li:focus {
  background: black;
}
/* line 161, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.lt-ie9 .top-bar section > ul > li.search:hover, .lt-ie9 .top-bar section > ul > li.search:focus, .lt-ie9 .top-bar section > ul > li.has-button:hover, .lt-ie9 .top-bar section > ul > li.has-button:focus {
  background: none;
}
/* line 162, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.lt-ie9 .top-bar section > ul > li.active {
  background: black;
  color: #d9d9d9;
}

/* line 164, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.lt-ie9 .top-bar ul li.has-dropdown {
  padding-right: 78.75px;
}
/* line 166, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_topbar.scss */
.lt-ie9 .top-bar ul li.has-dropdown > ul li {
  padding-right: 0;
}

/* CSS for jQuery Orbit Plugin 1.4.0
 * Maintained for Foundation. foundation.zurb.com
 * Free to use under the MIT license.
 * http://www.opensource.org/licenses/mit-license.php
*/
/* Container ---------------------- */
/* line 9, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper {
  width: 1px;
  height: 1px;
  position: relative;
}

/* line 11, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit {
  width: 1px;
  height: 1px;
  position: relative;
  overflow: hidden;
  margin-bottom: 17px;
}
/* line 13, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit.with-bullets {
  margin-bottom: 40px;
}
/* line 15, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit .orbit-slide {
  max-width: 100%;
  position: absolute;
  top: 0;
  left: 0;
}
/* line 16, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit a.orbit-slide {
  border: none;
  line-height: 0;
  display: none;
}
/* line 17, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit div.orbit-slide {
  width: 100%;
  height: 100%;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=0);
  opacity: 0;
}

/* Note: If your slider only uses content or anchors, you're going to want to put the width and height declarations on the ".orbit>div" and "div.orbit>a" tags in addition to just the .orbit-wrapper */
/* Timer ---------------------- */
/* line 25, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper .timer {
  width: 40px;
  height: 40px;
  overflow: hidden;
  position: absolute;
  top: 10px;
  right: 10px;
  opacity: .6;
  cursor: pointer;
  z-index: 31;
}
/* line 26, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper span.rotator {
  display: block;
  width: 40px;
  height: 40px;
  position: absolute;
  top: 0;
  left: -20px;
  background: url('foundation/orbit/rotator-black.png?1380562665') no-repeat;
  z-index: 3;
}
/* line 27, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper span.rotator.move {
  left: 0;
}
/* line 29, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper span.mask {
  display: block;
  width: 20px;
  height: 40px;
  position: absolute;
  top: 0;
  right: 0;
  z-index: 2;
  overflow: hidden;
}
/* line 30, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper span.mask.move {
  width: 40px;
  left: 0;
  background: url('foundation/orbit/timer-black.png?1380562665') repeat 0 0;
}
/* line 32, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper span.pause {
  display: block;
  width: 40px;
  height: 40px;
  position: absolute;
  top: 0;
  left: 0;
  background: url('foundation/orbit/pause-black.png?1380562665') no-repeat;
  z-index: 4;
  opacity: 0;
}
/* line 33, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper span.pause.active {
  background: url('foundation/orbit/pause-black.png?1380562665') no-repeat 0 -40px;
}
/* line 35, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper .timer:hover span.pause, .orbit-wrapper .timer:focus span.pause, .orbit-wrapper span.pause.active {
  opacity: 1;
}

/* Captions ---------------------- */
/* line 40, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-caption {
  display: none;
  font-family: inherit;
}

/* line 41, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper .orbit-caption {
  background: black;
  background: rgba(0, 0, 0, 0.6);
  z-index: 30;
  color: white;
  text-align: center;
  padding: 7px 0;
  font-size: 13px;
  position: absolute;
  right: 0;
  bottom: 0;
  width: 100%;
}

/* Directional Nav ---------------------- */
/* line 46, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper .slider-nav {
  display: block;
}
/* line 47, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper .slider-nav span {
  width: 39px;
  height: 50px;
  text-indent: -9999px;
  position: absolute;
  z-index: 30;
  top: 50%;
  margin-top: -25px;
  cursor: pointer;
}
/* line 48, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper .slider-nav span.right {
  background: url('foundation/orbit/right-arrow.png?1380562665');
  background-size: 100%;
  right: 0;
}
/* line 49, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-wrapper .slider-nav span.left {
  background: url('foundation/orbit/left-arrow.png?1380562665');
  background-size: 100%;
  left: 0;
}

/* line 54, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.lt-ie9 .orbit-wrapper .slider-nav span.right {
  background: url('foundation/orbit/right-arrow-small.png?1380562665');
}
/* line 55, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.lt-ie9 .orbit-wrapper .slider-nav span.left {
  background: url('foundation/orbit/left-arrow-small.png?1380562665');
}

/* Bullet Nav ---------------------- */
/* line 61, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
ul.orbit-bullets {
  position: absolute;
  z-index: 30;
  list-style: none;
  bottom: -40px;
  left: 50%;
  margin-left: -50px;
  padding: 0;
}
/* line 62, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
ul.orbit-bullets li {
  float: left;
  margin-left: 5px;
  cursor: pointer;
  color: #999999;
  text-indent: -9999px;
  background: url('foundation/orbit/bullets.jpg?1380562665') no-repeat 4px 0;
  width: 13px;
  height: 12px;
  overflow: hidden;
}
/* line 63, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
ul.orbit-bullets li.active {
  color: #222222;
  background-position: -8px 0;
}
/* line 64, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
ul.orbit-bullets li.has-thumb {
  background: none;
  width: 100px;
  height: 75px;
}
/* line 65, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
ul.orbit-bullets li.active.has-thumb {
  background-position: 0 0;
  border-top: 2px solid black;
}

/* Orbit Slide Counter */
/* line 70, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit-slide-counter {
  position: absolute;
  bottom: 0;
  z-index: 99;
  background: rgba(0, 0, 0, 0.7);
  color: white;
  padding: 5px;
}

/* Fluid Layout ---------------------- */
/* line 74, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit img.fluid-placeholder {
  visibility: hidden;
  position: static;
  display: block;
  width: 100%;
}

/* line 75, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.orbit, .orbit-wrapper {
  width: 100% !important;
}

/* Correct timer in IE */
/* line 78, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.lt-ie9 .timer {
  display: none !important;
}

/* line 79, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
.lt-ie9 .orbit-caption {
  background: black;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr=#99000000,endColorstr=#99000000);
  zoom: 1;
}

@media only screen and (max-width: 767px) {
  /* line 83, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
  .orbit.orbit-stack-on-small img.fluid-placeholder {
    visibility: visible;
  }

  /* line 86, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_orbit.scss */
  .orbit.orbit-stack-on-small .orbit-slide {
    position: static;
    margin-bottom: 10px;
  }
}
/* Visibility Classes ---------------------- */
/*                                           */
/* Standard (large) display targeting */
/* line 10, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
.show-for-small,
.show-for-medium,
.show-for-medium-down,
.hide-for-large,
.hide-for-large-up,
.show-for-xlarge,
.show-for-print {
  display: none !important;
}

/* line 18, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
.hide-for-small,
.hide-for-medium,
.hide-for-medium-down,
.show-for-large,
.show-for-large-up,
.hide-for-xlarge,
.hide-for-print {
  display: inherit !important;
}

/* Very large display targeting */
@media only screen and (min-width: 1441px) {
  /* line 27, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .hide-for-small,
  .hide-for-medium,
  .hide-for-medium-down,
  .hide-for-large,
  .show-for-large-up,
  .show-for-xlarge {
    display: inherit !important;
  }

  /* line 34, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .show-for-small,
  .show-for-medium,
  .show-for-medium-down,
  .show-for-large,
  .hide-for-large-up,
  .hide-for-xlarge {
    display: none !important;
  }
}
/* Medium display targeting */
@media only screen and (max-width: 1279px) and (min-width: 768px) {
  /* line 44, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .hide-for-small,
  .show-for-medium,
  .show-for-medium-down,
  .hide-for-large,
  .hide-for-large-up,
  .hide-for-xlarge {
    display: inherit !important;
  }

  /* line 51, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .show-for-small,
  .hide-for-medium,
  .hide-for-medium-down,
  .show-for-large,
  .show-for-large-up,
  .show-for-xlarge {
    display: none !important;
  }
}
/* Small display targeting */
@media only screen and (max-width: 767px) {
  /* line 61, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .show-for-small,
  .hide-for-medium,
  .show-for-medium-down,
  .hide-for-large,
  .hide-for-large-up,
  .hide-for-xlarge {
    display: inherit !important;
  }

  /* line 68, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .hide-for-small,
  .show-for-medium,
  .hide-for-medium-down,
  .show-for-large,
  .show-for-large-up,
  .show-for-xlarge {
    display: none !important;
  }
}
/* Orientation targeting */
/* line 73, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
.show-for-landscape,
.hide-for-portrait {
  display: inherit !important;
}

/* line 75, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
.hide-for-landscape,
.show-for-portrait {
  display: none !important;
}

@media screen and (orientation: landscape) {
  /* line 79, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .show-for-landscape,
  .hide-for-portrait {
    display: inherit !important;
  }

  /* line 81, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .hide-for-landscape,
  .show-for-portrait {
    display: none !important;
  }
}
@media screen and (orientation: portrait) {
  /* line 86, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .show-for-portrait,
  .hide-for-landscape {
    display: inherit !important;
  }

  /* line 88, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .hide-for-portrait,
  .show-for-landscape {
    display: none !important;
  }
}
/* Touch-enabled device targeting */
/* line 92, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
.show-for-touch {
  display: none !important;
}

/* line 93, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
.hide-for-touch {
  display: inherit !important;
}

/* line 94, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
.touch .show-for-touch {
  display: inherit !important;
}

/* line 95, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
.touch .hide-for-touch {
  display: none !important;
}

/* Specific overrides for elements that require something other than display: block */
/* line 102, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
table.show-for-xlarge,
table.show-for-large,
table.hide-for-small,
table.hide-for-medium {
  display: table !important;
}

@media only screen and (max-width: 1279px) and (min-width: 768px) {
  /* line 108, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .touch table.hide-for-xlarge,
  .touch table.hide-for-large,
  .touch table.hide-for-small,
  .touch table.show-for-medium {
    display: table !important;
  }
}
@media only screen and (max-width: 767px) {
  /* line 115, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  table.hide-for-xlarge,
  table.hide-for-large,
  table.hide-for-medium,
  table.show-for-small {
    display: table !important;
  }
}
/* 1280 tablet ------------ */
@media only screen and (max-device-width: 1280px) {
  /* NavBar --- */
  /*            */
  /* line 124, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .touch .nav-bar li.has-flyout > a {
    padding-right: 36px !important;
  }
}
/* Covering almost all ----- */
@media only screen and (max-device-width: 800px), only screen and (device-width: 1024px) and (device-height: 600px), only screen and (width: 1280px) and (orientation: landscape), only screen and (device-width: 800px), only screen and (max-width: 767px) {
  /* line 130, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .flex-video {
    padding-top: 0;
  }
}
/* Between Medium and Small */
@media only screen and (max-width: 1279px) and (min-width: 768px) {
  /* NavBar --- */
  /*            */
  /* line 139, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .touch .nav-bar li a {
    font-size: 13px;
  }
  /* line 141, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .touch .nav-bar li.has-flyout > a.flyout-toggle {
    padding: 20px !important;
  }
  /* line 142, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .touch .nav-bar li.has-flyout > a {
    padding-right: 36px !important;
  }

  /* Clearing --- */
  /*              */
  /* line 148, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-main-right, .clearing-main-left {
    height: 100%;
    width: 40px;
    top: 0;
    border: none;
  }
  /* line 153, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-main-right:before, .clearing-main-left:before {
    position: absolute;
    top: 50%;
  }

  /* line 155, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-main-left {
    left: 0;
  }
  /* line 157, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-main-left:before {
    left: 5px;
    content: "";
    display: block;
    width: 0;
    height: 0;
    border: solid 16px;
    border-color: transparent white transparent transparent;
  }

  /* line 159, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-main-right {
    height: 100%;
    right: 0;
  }
  /* line 162, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-main-right:before {
    content: "";
    display: block;
    width: 0;
    height: 0;
    border: solid 16px;
    border-color: transparent transparent transparent white;
  }
}
/* Small Devices ------------ */
@media only screen and (max-width: 767px) {
  /* Global Misc --- */
  /*                 */
  /* line 172, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .left, .right {
    float: none;
  }

  /* line 173, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  body {
    -webkit-text-size-adjust: none;
    -ms-text-size-adjust: none;
    width: 100%;
    min-width: 0;
    margin-left: 0;
    margin-right: 0;
    padding-left: 0;
    padding-right: 0;
  }

  /* The Grid --- */
  /*              */
  /* line 177, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row {
    width: auto;
    min-width: 0;
    margin-left: 0;
    margin-right: 0;
  }

  /* line 178, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .column, .columns {
    width: auto !important;
    float: none;
  }

  /* line 179, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .column:last-child, .columns:last-child {
    float: none;
  }

  /* line 180, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  [class*="column"] + [class*="column"]:last-child {
    float: none;
  }

  /* line 181, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .column:before, .columns:before, .column:after, .columns:after {
    content: "";
    display: table;
  }

  /* line 182, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .column:after, .columns:after {
    clear: both;
  }

  /* line 185, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .offset-by-one, .offset-by-two, .offset-by-three, .offset-by-four, .offset-by-five, .offset-by-six, .offset-by-seven, .offset-by-eight, .offset-by-nine, .offset-by-ten {
    margin-left: 0 !important;
  }

  /* line 186, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .push-two, .push-three, .push-four, .push-five, .push-six, .push-seven, .push-eight, .push-nine, .push-ten {
    left: auto;
  }

  /* line 187, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .pull-two, .pull-three, .pull-four, .pull-five, .pull-six, .pull-seven, .pull-eight, .pull-nine, .pull-ten {
    right: auto;
  }

  /* Mobile 4-column Grid */
  /* line 200, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-one {
    width: 25% !important;
    float: left;
    padding: 0 15px;
  }
  /* line 201, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-one:last-child {
    float: right;
  }
  /* line 202, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-one.end {
    float: left;
  }
  /* line 205, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row.collapse .mobile-one {
    padding: 0;
  }

  /* line 200, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-two {
    width: 50% !important;
    float: left;
    padding: 0 15px;
  }
  /* line 201, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-two:last-child {
    float: right;
  }
  /* line 202, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-two.end {
    float: left;
  }
  /* line 205, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row.collapse .mobile-two {
    padding: 0;
  }

  /* line 200, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-three {
    width: 75% !important;
    float: left;
    padding: 0 15px;
  }
  /* line 201, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-three:last-child {
    float: right;
  }
  /* line 202, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-three.end {
    float: left;
  }
  /* line 205, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row.collapse .mobile-three {
    padding: 0;
  }

  /* line 200, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-four {
    width: 100% !important;
    float: left;
    padding: 0 15px;
  }
  /* line 201, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-four:last-child {
    float: right;
  }
  /* line 202, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row .mobile-four.end {
    float: left;
  }
  /* line 205, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .row.collapse .mobile-four {
    padding: 0;
  }

  /* line 210, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .push-one-mobile {
    left: 25%;
  }

  /* line 211, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .pull-one-mobile {
    right: 25%;
  }

  /* line 210, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .push-two-mobile {
    left: 50%;
  }

  /* line 211, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .pull-two-mobile {
    right: 50%;
  }

  /* line 210, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .push-three-mobile {
    left: 75%;
  }

  /* line 211, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .pull-three-mobile {
    right: 75%;
  }

  /* Block Grids --- */
  /*                 */
  /* line 217, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile > li {
    float: none;
    width: 100%;
    margin-left: 0;
  }

  /* line 221, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid > li {
    clear: none;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-one-up > li {
    width: 100%;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-two-up > li {
    width: 50%;
  }
  /* line 225, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-two-up > li:nth-child(2n+1) {
    clear: both;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-three-up > li {
    width: 33.33333%;
  }
  /* line 225, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-three-up > li:nth-child(3n+1) {
    clear: both;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-four-up > li {
    width: 25%;
  }
  /* line 225, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-four-up > li:nth-child(4n+1) {
    clear: both;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-five-up > li {
    width: 20%;
  }
  /* line 225, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-five-up > li:nth-child(5n+1) {
    clear: both;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-six-up > li {
    width: 16.66667%;
  }
  /* line 225, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-six-up > li:nth-child(6n+1) {
    clear: both;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-seven-up > li {
    width: 14.28571%;
  }
  /* line 225, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-seven-up > li:nth-child(7n+1) {
    clear: both;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-eight-up > li {
    width: 12.5%;
  }
  /* line 225, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-eight-up > li:nth-child(8n+1) {
    clear: both;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-nine-up > li {
    width: 11.11111%;
  }
  /* line 225, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-nine-up > li:nth-child(9n+1) {
    clear: both;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-ten-up > li {
    width: 10%;
  }
  /* line 225, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-ten-up > li:nth-child(10n+1) {
    clear: both;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-eleven-up > li {
    width: 9.09091%;
  }
  /* line 225, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-eleven-up > li:nth-child(11n+1) {
    clear: both;
  }
  /* line 223, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-twelve-up > li {
    width: 8.33333%;
  }
  /* line 225, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .block-grid.mobile-twelve-up > li:nth-child(12n+1) {
    clear: both;
  }

  /* Forms --- */
  /*           */
  /* Label alignment */
  /* line 234, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  label.right {
    text-align: left;
  }

  /* Extend width of all inputs */
  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].one, .row input[type="text"].one,
  input[type="password"].one,
  .row input[type="password"].one,
  input[type="date"].one,
  .row input[type="date"].one,
  input[type="datetime"].one,
  .row input[type="datetime"].one,
  input[type="email"].one,
  .row input[type="email"].one,
  input[type="number"].one,
  .row input[type="number"].one,
  input[type="search"].one,
  .row input[type="search"].one,
  input[type="tel"].one,
  .row input[type="tel"].one,
  input[type="time"].one,
  .row input[type="time"].one,
  input[type="url"].one,
  .row input[type="url"].one,
  textarea.one,
  .row textarea.one {
    width: 100% !important;
  }

  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].two, .row input[type="text"].two,
  input[type="password"].two,
  .row input[type="password"].two,
  input[type="date"].two,
  .row input[type="date"].two,
  input[type="datetime"].two,
  .row input[type="datetime"].two,
  input[type="email"].two,
  .row input[type="email"].two,
  input[type="number"].two,
  .row input[type="number"].two,
  input[type="search"].two,
  .row input[type="search"].two,
  input[type="tel"].two,
  .row input[type="tel"].two,
  input[type="time"].two,
  .row input[type="time"].two,
  input[type="url"].two,
  .row input[type="url"].two,
  textarea.two,
  .row textarea.two {
    width: 100% !important;
  }

  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].three, .row input[type="text"].three,
  input[type="password"].three,
  .row input[type="password"].three,
  input[type="date"].three,
  .row input[type="date"].three,
  input[type="datetime"].three,
  .row input[type="datetime"].three,
  input[type="email"].three,
  .row input[type="email"].three,
  input[type="number"].three,
  .row input[type="number"].three,
  input[type="search"].three,
  .row input[type="search"].three,
  input[type="tel"].three,
  .row input[type="tel"].three,
  input[type="time"].three,
  .row input[type="time"].three,
  input[type="url"].three,
  .row input[type="url"].three,
  textarea.three,
  .row textarea.three {
    width: 100% !important;
  }

  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].four, .row input[type="text"].four,
  input[type="password"].four,
  .row input[type="password"].four,
  input[type="date"].four,
  .row input[type="date"].four,
  input[type="datetime"].four,
  .row input[type="datetime"].four,
  input[type="email"].four,
  .row input[type="email"].four,
  input[type="number"].four,
  .row input[type="number"].four,
  input[type="search"].four,
  .row input[type="search"].four,
  input[type="tel"].four,
  .row input[type="tel"].four,
  input[type="time"].four,
  .row input[type="time"].four,
  input[type="url"].four,
  .row input[type="url"].four,
  textarea.four,
  .row textarea.four {
    width: 100% !important;
  }

  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].five, .row input[type="text"].five,
  input[type="password"].five,
  .row input[type="password"].five,
  input[type="date"].five,
  .row input[type="date"].five,
  input[type="datetime"].five,
  .row input[type="datetime"].five,
  input[type="email"].five,
  .row input[type="email"].five,
  input[type="number"].five,
  .row input[type="number"].five,
  input[type="search"].five,
  .row input[type="search"].five,
  input[type="tel"].five,
  .row input[type="tel"].five,
  input[type="time"].five,
  .row input[type="time"].five,
  input[type="url"].five,
  .row input[type="url"].five,
  textarea.five,
  .row textarea.five {
    width: 100% !important;
  }

  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].six, .row input[type="text"].six,
  input[type="password"].six,
  .row input[type="password"].six,
  input[type="date"].six,
  .row input[type="date"].six,
  input[type="datetime"].six,
  .row input[type="datetime"].six,
  input[type="email"].six,
  .row input[type="email"].six,
  input[type="number"].six,
  .row input[type="number"].six,
  input[type="search"].six,
  .row input[type="search"].six,
  input[type="tel"].six,
  .row input[type="tel"].six,
  input[type="time"].six,
  .row input[type="time"].six,
  input[type="url"].six,
  .row input[type="url"].six,
  textarea.six,
  .row textarea.six {
    width: 100% !important;
  }

  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].seven, .row input[type="text"].seven,
  input[type="password"].seven,
  .row input[type="password"].seven,
  input[type="date"].seven,
  .row input[type="date"].seven,
  input[type="datetime"].seven,
  .row input[type="datetime"].seven,
  input[type="email"].seven,
  .row input[type="email"].seven,
  input[type="number"].seven,
  .row input[type="number"].seven,
  input[type="search"].seven,
  .row input[type="search"].seven,
  input[type="tel"].seven,
  .row input[type="tel"].seven,
  input[type="time"].seven,
  .row input[type="time"].seven,
  input[type="url"].seven,
  .row input[type="url"].seven,
  textarea.seven,
  .row textarea.seven {
    width: 100% !important;
  }

  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].eight, .row input[type="text"].eight,
  input[type="password"].eight,
  .row input[type="password"].eight,
  input[type="date"].eight,
  .row input[type="date"].eight,
  input[type="datetime"].eight,
  .row input[type="datetime"].eight,
  input[type="email"].eight,
  .row input[type="email"].eight,
  input[type="number"].eight,
  .row input[type="number"].eight,
  input[type="search"].eight,
  .row input[type="search"].eight,
  input[type="tel"].eight,
  .row input[type="tel"].eight,
  input[type="time"].eight,
  .row input[type="time"].eight,
  input[type="url"].eight,
  .row input[type="url"].eight,
  textarea.eight,
  .row textarea.eight {
    width: 100% !important;
  }

  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].nine, .row input[type="text"].nine,
  input[type="password"].nine,
  .row input[type="password"].nine,
  input[type="date"].nine,
  .row input[type="date"].nine,
  input[type="datetime"].nine,
  .row input[type="datetime"].nine,
  input[type="email"].nine,
  .row input[type="email"].nine,
  input[type="number"].nine,
  .row input[type="number"].nine,
  input[type="search"].nine,
  .row input[type="search"].nine,
  input[type="tel"].nine,
  .row input[type="tel"].nine,
  input[type="time"].nine,
  .row input[type="time"].nine,
  input[type="url"].nine,
  .row input[type="url"].nine,
  textarea.nine,
  .row textarea.nine {
    width: 100% !important;
  }

  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].ten, .row input[type="text"].ten,
  input[type="password"].ten,
  .row input[type="password"].ten,
  input[type="date"].ten,
  .row input[type="date"].ten,
  input[type="datetime"].ten,
  .row input[type="datetime"].ten,
  input[type="email"].ten,
  .row input[type="email"].ten,
  input[type="number"].ten,
  .row input[type="number"].ten,
  input[type="search"].ten,
  .row input[type="search"].ten,
  input[type="tel"].ten,
  .row input[type="tel"].ten,
  input[type="time"].ten,
  .row input[type="time"].ten,
  input[type="url"].ten,
  .row input[type="url"].ten,
  textarea.ten,
  .row textarea.ten {
    width: 100% !important;
  }

  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].eleven, .row input[type="text"].eleven,
  input[type="password"].eleven,
  .row input[type="password"].eleven,
  input[type="date"].eleven,
  .row input[type="date"].eleven,
  input[type="datetime"].eleven,
  .row input[type="datetime"].eleven,
  input[type="email"].eleven,
  .row input[type="email"].eleven,
  input[type="number"].eleven,
  .row input[type="number"].eleven,
  input[type="search"].eleven,
  .row input[type="search"].eleven,
  input[type="tel"].eleven,
  .row input[type="tel"].eleven,
  input[type="time"].eleven,
  .row input[type="time"].eleven,
  input[type="url"].eleven,
  .row input[type="url"].eleven,
  textarea.eleven,
  .row textarea.eleven {
    width: 100% !important;
  }

  /* line 247, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  input[type="text"].twelve, .row input[type="text"].twelve,
  input[type="password"].twelve,
  .row input[type="password"].twelve,
  input[type="date"].twelve,
  .row input[type="date"].twelve,
  input[type="datetime"].twelve,
  .row input[type="datetime"].twelve,
  input[type="email"].twelve,
  .row input[type="email"].twelve,
  input[type="number"].twelve,
  .row input[type="number"].twelve,
  input[type="search"].twelve,
  .row input[type="search"].twelve,
  input[type="tel"].twelve,
  .row input[type="tel"].twelve,
  input[type="time"].twelve,
  .row input[type="time"].twelve,
  input[type="url"].twelve,
  .row input[type="url"].twelve,
  textarea.twelve,
  .row textarea.twelve {
    width: 100% !important;
  }

  /* Buttons --- */
  /*             */
  /* Basic overrides */
  /* line 261, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .button {
    display: block;
  }

  /* line 262, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  button.button, input[type="submit"].button, input[type="reset"].button {
    width: 100%;
    padding-left: 0;
    padding-right: 0;
  }

  /* Button Groups */
  /* line 265, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .button-group button.button, .button-group input[type="submit"].button {
    width: auto;
    padding: 10px 20px 11px;
  }
  /* line 266, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .button-group button.button.large, .button-group input[type="submit"].button.large {
    padding: 15px 30px 16px;
  }
  /* line 267, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .button-group button.button.medium, .button-group input[type="submit"].button.medium {
    padding: 10px 20px 11px;
  }
  /* line 268, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .button-group button.button.small, .button-group input[type="submit"].button.small {
    padding: 7px 14px 8px;
  }
  /* line 269, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .button-group button.button.tiny, .button-group input[type="submit"].button.tiny {
    padding: 5px 10px 6px;
  }
  /* line 271, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .button-group.even button.button, .button-group.even input[type="submit"].button {
    width: 100%;
    padding-left: 0;
    padding-right: 0;
  }

  /* Navbar --- */
  /*            */
  /* line 276, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .nav-bar {
    height: auto;
  }
  /* line 277, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .nav-bar > li {
    float: none;
    display: block;
    border-right: none;
  }
  /* line 278, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .nav-bar > li > a.main {
    text-align: left;
    border-top: 1px solid #ddd;
    border-right: none;
  }
  /* line 279, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .nav-bar > li:first-child > a.main {
    border-top: none;
  }
  /* line 280, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .nav-bar > li.has-flyout > a.flyout-toggle {
    position: absolute;
    right: 0;
    top: 0;
    padding: 22px;
    z-index: 2;
    display: block;
  }
  /* line 281, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .nav-bar > li.has-flyout.is-touch > a.flyout-toggle span {
    content: "";
    width: 0;
    height: 0;
    display: block;
  }
  /* line 282, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .nav-bar > li.has-flyout > a.flyout-toggle:hover span {
    border-top-color: #141414;
  }
  /* line 283, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .nav-bar.vertical > li.has-flyout > .flyout {
    left: 0;
  }

  /* line 285, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .flyout {
    position: relative;
    width: 100% !important;
    top: auto;
    margin-right: -2px;
    border-width: 1px 1px 0 1px;
  }
  /* line 286, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .flyout.right {
    float: none;
    right: auto;
    left: -1px;
  }
  /* line 287, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .flyout.small, .flyout.large {
    width: 100% !important;
  }
  /* line 288, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .flyout p:last-child {
    margin-bottom: 18px;
  }

  /* Reveal --- */
  /*            */
  /* line 293, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .reveal-modal-bg {
    position: absolute;
  }

  /* line 298, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .reveal-modal,
  .reveal-modal.small,
  .reveal-modal.medium,
  .reveal-modal.large,
  .reveal-modal.xlarge {
    width: 80%;
    top: 15px;
    left: 50%;
    margin-left: -40%;
    padding: 20px;
    height: auto;
  }

  /* Clearing --- */
  /*              */
  /* line 302, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-container {
    margin: 0;
  }

  /* line 303, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-close {
    z-index: 99;
    font-size: 37px;
    top: 0px;
    right: 5px;
  }

  /* line 304, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-caption {
    position: fixed;
    bottom: 0;
    left: 0;
    padding: 10px !important;
    line-height: 1.3;
  }

  /* line 305, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-main-right, .clearing-main-left {
    display: none;
  }

  /* line 307, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-blackout.clearing-assembled .visible-img, .clearing-blackout.clearing-assembled .clearing-container {
    height: 100%;
  }
  /* line 308, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .clearing-blackout.clearing-assembled ul[data-clearing] {
    display: none;
  }

  /* Joyride --- */
  /*             */
  /* line 313, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .joyride-tip-guide {
    width: 95% !important;
    left: 2.5% !important;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    -ms-border-radius: 4px;
    -o-border-radius: 4px;
    border-radius: 4px;
  }

  /* line 314, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .joyride-tip-guide-wrapper {
    width: 100%;
  }

  /* Tabs --- */
  /*          */
  /* line 318, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .tabs.mobile {
    width: auto;
    margin: 20px -20px 40px;
    border-bottom: solid 1px #ccc;
    height: auto;
    margin: 20px -15px 0px -15px;
  }
  /* line 319, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .tabs.mobile dt, .tabs.mobile li, .tabs.mobile dd {
    float: none;
    height: auto;
  }
  /* line 320, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .tabs.mobile dd a, .tabs.mobile li a {
    font-size: 15px;
    display: block;
    width: auto;
    height: auto;
    padding: 18px 20px;
    margin: 0;
    color: #555;
    line-height: 1;
    border: none;
    border-left: none;
    border-right: none;
    border-top: 1px solid #ccc;
    background: #fff;
  }
  /* line 321, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .tabs.mobile dd a.active, .tabs.mobile li a.active {
    border: none;
    background: #fd9c00;
    color: #fff;
    margin: 0;
    position: static;
    top: 0;
    height: auto;
  }
  /* line 322, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .tabs.mobile dd:first-child a.active, .tabs.mobile li:first-child a.active {
    margin: 0;
  }
  /* line 323, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .tabs.mobile + .tabs-content.contained {
    margin-left: -15px;
    margin-right: -15px;
  }
  /* line 324, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .tabs.mobile .section-title {
    padding-left: 20px !important;
  }

  /* line 327, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .contained.mobile {
    margin-bottom: 0;
  }

  /* line 328, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .contained.tabs.mobile dd a, .contained.tabs.mobile li a {
    padding: 18px 20px;
  }

  /* line 329, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .tabs.mobile + ul.contained {
    margin-left: -20px;
    margin-right: -20px;
    border-width: 0 0 1px 0;
  }

  /* UI Elements --- */
  /*                 */
  /* Tooltips */
  /* line 334, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .tooltip {
    font-size: 14px;
    line-height: 1.4;
    padding: 7px 10px 9px 10px;
    left: 50% !important;
    max-width: 80% !important;
    margin-left: -40%;
    font-size: 110%;
  }

  /* line 343, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .tooltip > .nub, .tooltip.top > .nub, .tooltip.left > .nub, .tooltip.right > .nub {
    border-color: transparent transparent black transparent;
    border-color: transparent transparent rgba(0, 0, 0, 0.85) transparent;
    top: -12px;
    left: 10px;
  }
}
/* Topbar Specific Breakpoint that you can customize */
@media only screen and (max-width: 940px) {
  /* line 354, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar {
    margin-bottom: 0;
    overflow: hidden;
    height: 105px;
    background: #222222;
    /* Override contain to grid stuff for breakpoint */
    /* Setting up the sliding area */
    /* When the Small Nav is Showing */
  }
  /* line 355, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar .js-generated {
    display: block;
  }
  /* line 358, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .contain-to-grid .top-bar {
    width: auto;
  }
  /* line 361, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar section {
    left: 0;
    position: relative;
    width: auto;
    -webkit-transition: left 300ms 0;
    -moz-transition: left 300ms 0;
    -o-transition: left 300ms 0;
    transition: left 300ms 0;
  }
  /* line 362, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul {
    width: 100%;
    height: 100%;
    margin-bottom: 0;
    display: block;
  }
  /* line 363, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li {
    float: none;
    /* Branding and name */
    /* Dropdown Toggle */
    /* Divider for breakpoint */
    /* Search Overrides for breakpoint size */
    /* Dropdown Level 1 */
    /* Dropdown Level 2 */
  }
  /* line 364, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.active, .top-bar ul > li:hover {
    background: #151515;
  }
  /* line 366, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.name {
    height: 105px;
  }
  /* line 367, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.name h1 {
    line-height: 1;
  }
  /* line 368, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.name h1 a {
    color: white;
    display: block;
    line-height: 105px !important;
    padding-left: 35px;
    height: 105px;
  }
  /* line 371, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li:hover a, .top-bar ul > li.active a {
    color: white;
  }
  /* line 372, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li a:not(.button) {
    color: white;
  }
  /* line 375, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.toggle-topbar {
    cursor: pointer;
    display: block;
    height: 105px;
    position: absolute;
    right: 0;
    top: 0;
    width: 50%;
  }
  /* line 376, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.toggle-topbar a {
    content: "";
    display: block;
    width: 0;
    height: 0;
    border: solid 8px;
    border-color: white transparent transparent transparent;
    padding: 0;
    position: absolute;
    top: 50%;
    right: 52.5px;
    margin-top: -4px;
  }
  /* line 378, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.toggle-topbar:hover {
    background: inherit;
  }
  /* line 380, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.toggle-topbar a {
    padding: 0 !important;
  }
  /* line 383, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.divider {
    border-bottom: solid 1px #3c3c3c;
    border-top: solid 1px black;
    clear: both;
    height: 1px !important;
    margin: 8px 0 !important;
    width: 100%;
  }
  /* line 386, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.search {
    padding: 0 52.5px;
  }
  /* line 387, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.search form {
    width: 100%;
  }
  /* line 388, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.search form input[type=text] {
    width: 75%;
  }
  /* line 389, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.search form .button {
    top: -1px;
    width: 25%;
  }
  /* line 395, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown a {
    padding-right: 78.75px;
  }
  /* line 396, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown a:after {
    content: "";
    display: block;
    width: 0;
    height: 0;
    border: solid 5px;
    border-color: transparent transparent transparent rgba(255, 255, 255, 0.5);
    margin-right: 35px;
    margin-top: -4.5px;
    position: absolute;
    top: 50%;
  }
  /* line 398, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown:hover > .dropdown {
    display: block;
    visibility: hidden;
  }
  /* line 399, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown .dropdown {
    visibility: hidden;
    z-index: 0 !important;
  }
  /* line 400, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved {
    position: static;
  }
  /* line 401, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved > .dropdown {
    top: 0;
    visibility: visible;
  }
  /* line 403, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved > .dropdown li label {
    margin-bottom: 6px;
    padding-top: 6px !important;
    font-size: 11px;
  }
  /* line 404, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved > .dropdown li:not(.title) {
    padding-bottom: 0;
  }
  /* line 405, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved > .dropdown li:not(.title) a {
    padding: 8px 52.5px;
    font-size: 14px;
  }
  /* line 407, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved > .dropdown li a, .top-bar ul > li.has-dropdown.moved > .dropdown li label {
    padding: 0 52.5px;
  }
  /* line 408, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved > .dropdown li a:hover {
    background: #1a1a1a;
    display: block;
  }
  /* line 409, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved > .dropdown li.divider {
    border-bottom: solid 1px rgba(255, 255, 255, 0.1);
    margin-top: 8px !important;
    margin-bottom: 8px !important;
  }
  /* line 412, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved .back.title {
    padding-bottom: 0;
  }
  /* line 413, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved .back.title a:before {
    position: absolute;
    top: 50%;
    left: 47.5px;
    margin-top: -5px;
    width: 0;
    height: 0;
    content: "";
    display: block;
    width: 0;
    height: 0;
    border: solid 5px;
    border-color: transparent white transparent transparent;
  }
  /* line 414, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved .back.title h5 {
    margin: 0;
    padding-left: 15px;
    position: relative;
  }
  /* line 415, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown.moved .back.title h5 a {
    background: transparent;
    padding-top: 8px;
    padding-bottom: 8px;
    font-size: 23px;
    font-weight: bold;
  }
  /* line 422, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown .dropdown li {
    background: transparent;
  }
  /* line 424, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown .dropdown li.has-dropdown .dropdown {
    left: 100% !important;
    top: 0;
    right: auto !important;
  }
  /* line 425, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown .dropdown li.has-dropdown > a {
    padding-right: 78.75px;
  }
  /* line 426, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown .dropdown li.has-dropdown > a:after {
    content: "";
    margin-right: 35px;
    content: "";
    display: block;
    width: 0;
    height: 0;
    border: solid 5px;
    border-color: transparent transparent transparent rgba(255, 255, 255, 0.5);
    position: absolute;
    top: 50%;
    margin-top: -4.5px;
  }
  /* line 428, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown .dropdown li.has-dropdown > a li a:hover {
    background: #1a1a1a;
  }
  /* line 431, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown .dropdown li.has-dropdown.moved {
    position: static;
  }
  /* line 432, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown .dropdown li.has-dropdown.moved .dropdown {
    top: 0;
    visibility: visible;
  }
  /* line 434, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-dropdown .dropdown li.has-dropdown:hover {
    display: block;
  }
  /* line 438, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul.left, .top-bar ul.right {
    float: none;
    width: 100%;
  }
  /* line 439, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul.left > li, .top-bar ul.right > li {
    display: block;
    float: none;
    margin: 0 !important;
  }
  /* line 441, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul.left > li.has-dropdown .dropdown, .top-bar ul.right > li.has-dropdown .dropdown {
    left: 100% !important;
    top: 0;
    right: auto !important;
  }
  /* line 446, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar section > ul li a:not(.button) {
    padding-left: 52.5px !important;
  }
  /* line 449, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar.expanded {
    height: 100%;
  }
  /* line 450, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar.expanded ul li.toggle-topbar a {
    content: "";
    display: block;
    width: 0;
    height: 0;
    border: solid 8px;
    border-color: transparent transparent #cccccc transparent;
    top: auto;
    bottom: 50%;
    margin-bottom: -4px;
  }

  /* line 453, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul li.has-button {
    padding: 5px 35px;
  }

  /* line 454, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul li .button.small {
    margin: 0 !important;
    display: inline-block;
    width: 100%;
  }

  /* line 456, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/components/modules/_mqueries.scss */
  .top-bar ul > li.has-button a.button {
    margin: 0;
  }
}
/* The SCSS where fonts are loaded and existing icons are declared, need to 
 * import the base before
 */
/*
 *  Font Awesome 3.0.2
 *  the iconic font designed for use with Twitter Bootstrap
 *  -------------------------------------------------------
 *  The full suite of pictographic icons, examples, and documentation
 *  can be found at: http://fortawesome.github.com/Font-Awesome/
 *
 *  License
 *  -------------------------------------------------------
 *  - The Font Awesome font is licensed under the SIL Open Font License - http://scripts.sil.org/OFL
 *  - Font Awesome CSS, LESS, and SASS files are licensed under the MIT License -
 *    http://opensource.org/licenses/mit-license.html
 *  - The Font Awesome pictograms are licensed under the CC BY 3.0 License - http://creativecommons.org/licenses/by/3.0/
 *  - Attribution is no longer required in Font Awesome 3.0, but much appreciated:
 *    "Font Awesome by Dave Gandy - http://fortawesome.github.com/Font-Awesome"
 *
 *  Contact
 *  -------------------------------------------------------
 *  Email: dave@davegandy.com
 *  Twitter: http://twitter.com/fortaweso_me
 *  Work: Lead Product Designer @ http://kyruus.com
 */
/*  Font Awesome styles
    ------------------------------------------------------- */
/* line 32, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
[class^="icon-"],
[class*=" icon-"] {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  text-decoration: inherit;
  -webkit-font-smoothing: antialiased;
  /* sprites.less reset */
  display: inline;
  width: auto;
  height: auto;
  line-height: normal;
  vertical-align: baseline;
  background-image: none;
  background-position: 0% 0%;
  background-repeat: repeat;
  margin-top: 0;
}

/* more sprites.less reset */
/* line 64, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.icon-white,
.nav-pills > .active > a > [class^="icon-"],
.nav-pills > .active > a > [class*=" icon-"],
.nav-list > .active > a > [class^="icon-"],
.nav-list > .active > a > [class*=" icon-"],
.navbar-inverse .nav > .active > a > [class^="icon-"],
.navbar-inverse .nav > .active > a > [class*=" icon-"],
.dropdown-menu > li > a:hover > [class^="icon-"],
.dropdown-menu > li > a:hover > [class*=" icon-"],
.dropdown-menu > .active > a > [class^="icon-"],
.dropdown-menu > .active > a > [class*=" icon-"],
.dropdown-submenu:hover > a > [class^="icon-"],
.dropdown-submenu:hover > a > [class*=" icon-"] {
  background-image: none;
}

/* line 69, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
[class^="icon-"]:before,
[class*=" icon-"]:before {
  text-decoration: inherit;
  display: inline-block;
  speak: none;
}

/* makes sure icons active on rollover in links */
/* line 78, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
a [class^="icon-"],
a [class*=" icon-"] {
  display: inline-block;
}

/* makes the font 33% larger relative to the icon container */
/* line 84, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.icon-large:before {
  vertical-align: -10%;
  font-size: 1.3333333333333333em;
}

/* line 91, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.button [class^="icon-"],
.button [class*=" icon-"], .nav [class^="icon-"],
.nav [class*=" icon-"] {
  display: inline;
  /* keeps button heights with and without icons the same */
}
/* line 94, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.button [class^="icon-"].icon-large,
.button [class*=" icon-"].icon-large, .nav [class^="icon-"].icon-large,
.nav [class*=" icon-"].icon-large {
  line-height: .9em;
}
/* line 95, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.button [class^="icon-"].icon-spin,
.button [class*=" icon-"].icon-spin, .nav [class^="icon-"].icon-spin,
.nav [class*=" icon-"].icon-spin {
  display: inline-block;
}

/* line 101, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.nav-tabs [class^="icon-"],
.nav-tabs [class*=" icon-"], .nav-pills [class^="icon-"],
.nav-pills [class*=" icon-"] {
  /* keeps button heights with and without icons the same */
}
/* line 103, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.nav-tabs [class^="icon-"], .nav-tabs [class^="icon-"].icon-large,
.nav-tabs [class*=" icon-"],
.nav-tabs [class*=" icon-"].icon-large, .nav-pills [class^="icon-"], .nav-pills [class^="icon-"].icon-large,
.nav-pills [class*=" icon-"],
.nav-pills [class*=" icon-"].icon-large {
  line-height: .9em;
}

/* line 109, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
li [class^="icon-"],
li [class*=" icon-"], .nav li [class^="icon-"],
.nav li [class*=" icon-"] {
  display: inline-block;
  width: 1.25em;
  text-align: center;
}
/* line 113, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
li [class^="icon-"].icon-large,
li [class*=" icon-"].icon-large, .nav li [class^="icon-"].icon-large,
.nav li [class*=" icon-"].icon-large {
  /* increased font size for icon-large */
  width: 1.5625em;
}

/* line 120, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
ul.icons {
  list-style-type: none;
  text-indent: -0.75em;
}
/* line 126, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
ul.icons li [class^="icon-"],
ul.icons li [class*=" icon-"] {
  width: .75em;
}

/* line 132, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.icon-muted {
  color: #eeeeee;
}

/* line 137, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.sticked-icon {
  display: block;
  position: relative;
  padding-left: 5em;
}
/* line 143, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.sticked-icon[class^="icon-"]:before, .sticked-icon[class*="icon-"]:before {
  position: absolute;
  top: 17px;
  left: 17px;
  font-size: 4em;
}

/* line 154, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.icon-border {
  border: solid 1px #eeeeee;
  padding: .2em .25em .15em;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}

/* line 163, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.icon-2x {
  font-size: 2em;
}
/* line 165, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.icon-2x.icon-border {
  border-width: 2px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}

/* line 170, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.icon-3x {
  font-size: 3em;
}
/* line 172, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.icon-3x.icon-border {
  border-width: 3px;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
}

/* line 177, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.icon-4x {
  font-size: 4em;
}
/* line 179, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.icon-4x.icon-border {
  border-width: 4px;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
}

/* line 189, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.right {
  float: right;
}

/* line 190, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.left {
  float: left;
}

/* line 194, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
[class^="icon-"].left,
[class*=" icon-"].left {
  margin-right: .3em;
}
/* line 197, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
[class^="icon-"].right,
[class*=" icon-"].right {
  margin-left: .3em;
}

/* line 206, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.button [class^="icon-"].left.icon-2x, .button [class^="icon-"].right.icon-2x,
.button [class*=" icon-"].left.icon-2x,
.button [class*=" icon-"].right.icon-2x {
  margin-top: .18em;
}
/* line 208, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.button [class^="icon-"].icon-spin.icon-large,
.button [class*=" icon-"].icon-spin.icon-large {
  line-height: .8em;
}

/* line 216, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.button.small [class^="icon-"].left.icon-2x, .button.small [class^="icon-"].right.icon-2x,
.button.small [class*=" icon-"].left.icon-2x,
.button.small [class*=" icon-"].right.icon-2x {
  margin-top: .25em;
}

/* line 223, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.button.large [class^="icon-"],
.button.large [class*=" icon-"] {
  margin-top: 0;
}
/* line 226, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.button.large [class^="icon-"].left.icon-2x, .button.large [class^="icon-"].right.icon-2x,
.button.large [class*=" icon-"].left.icon-2x,
.button.large [class*=" icon-"].right.icon-2x {
  margin-top: .05em;
}
/* line 228, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.button.large [class^="icon-"].left.icon-2x,
.button.large [class*=" icon-"].left.icon-2x {
  margin-right: .2em;
}
/* line 229, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.button.large [class^="icon-"].right.icon-2x,
.button.large [class*=" icon-"].right.icon-2x {
  margin-left: .2em;
}

/* line 234, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
.icon-spin {
  display: inline-block;
  -moz-animation: spin 2s infinite linear;
  -o-animation: spin 2s infinite linear;
  -webkit-animation: spin 2s infinite linear;
  animation: spin 2s infinite linear;
}

@-moz-keyframes spin {
  /* line 243, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  0% {
    -moz-transform: rotate(0deg);
  }

  /* line 244, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  100% {
    -moz-transform: rotate(359deg);
  }
}

@-webkit-keyframes spin {
  /* line 247, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  0% {
    -webkit-transform: rotate(0deg);
  }

  /* line 248, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  100% {
    -webkit-transform: rotate(359deg);
  }
}

@-o-keyframes spin {
  /* line 251, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  0% {
    -o-transform: rotate(0deg);
  }

  /* line 252, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  100% {
    -o-transform: rotate(359deg);
  }
}

@-ms-keyframes spin {
  /* line 255, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  0% {
    -ms-transform: rotate(0deg);
  }

  /* line 256, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  100% {
    -ms-transform: rotate(359deg);
  }
}

@keyframes spin {
  /* line 259, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  0% {
    transform: rotate(0deg);
  }

  /* line 260, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  100% {
    transform: rotate(359deg);
  }
}

@-moz-document url-prefix() {
  /* line 264, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  .icon-spin {
    height: .9em;
  }

  /* line 265, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  .button .icon-spin {
    height: auto;
  }

  /* line 266, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  .icon-spin.icon-large {
    height: 1.25em;
  }

  /* line 267, /home/django/Emencia/cnct/compass/scss/components/_font-awesome_base.scss */
  .button .icon-spin.icon-large {
    height: .75em;
  }
}

@font-face {
  font-family: 'fontawesome';
  src: url("../fonts/fontawesome.eot");
  src: url("../fonts/fontawesome.eot?#iefix") format("embedded-opentype"), url("../fonts/fontawesome.woff") format("woff"), url("../fonts/fontawesome.ttf") format("truetype"), url("../fonts/fontawesome.svg#fontawesome") format("svg");
  font-weight: normal;
  font-style: normal;
}

/* line 19, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-youtube:before {
  content: "\f30e";
}

/* line 22, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-facebook:before {
  content: "\f09a";
}

/* line 25, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-twitter:before {
  content: "\f099";
}

/* line 28, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-search:before {
  content: "\f002";
}

/* line 31, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-google-plus:before {
  content: "\f0d5";
}

/* line 34, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-chevron-left:before {
  content: "\f053";
}

/* line 37, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-chevron-right:before {
  content: "\f054";
}

/* line 40, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-apple:before {
  content: "\f344";
}

/* line 43, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-android:before {
  content: "\f342";
}

/* line 46, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-acrobat:before {
  content: "\f206";
}

/* line 49, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-download-alt:before {
  content: "\f019";
}

/* line 52, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-refresh:before {
  content: "\f021";
}

/* line 55, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-question-sign:before {
  content: "\f059";
}

/* line 58, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-volume-up:before {
  content: "\f028";
}

/* line 61, /home/django/Emencia/cnct/compass/scss/components/_font-awesome.scss */
.icon-picture:before {
  content: "\f03e";
}

/* 
 * Country flags sprites
 */
/* line 202, flags/flags-24/*.png */
.flags-24-sprite, .flags-24-ar-ma, .flags-24-cs, .flags-24-de, .flags-24-en-au, .flags-24-en-gb, .flags-24-en-nz, .flags-24-en-us, .flags-24-es-cl, .flags-24-es-co, .flags-24-es, .flags-24-fr, .flags-24-hu-si, .flags-24-it, .flags-24-ja, .flags-24-nl, .flags-24-pl, .flags-24-pt-br, .flags-24-ru, .flags-24-ss-za, .flags-24-tr, .flags-24-zh-cn {
  background: url('../images/flags/flags-24-sa282d84023.png') no-repeat;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-ar-ma {
  background-position: 0 -192px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-cs {
  background-position: 0 -96px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-de {
  background-position: 0 -288px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-en-au {
  background-position: 0 -16px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-en-gb {
  background-position: 0 0;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-en-nz {
  background-position: 0 -64px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-en-us {
  background-position: 0 -112px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-es-cl {
  background-position: 0 -224px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-es-co {
  background-position: 0 -272px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-es {
  background-position: 0 -160px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-fr {
  background-position: 0 -176px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-hu-si {
  background-position: 0 -240px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-it {
  background-position: 0 -128px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-ja {
  background-position: 0 -144px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-nl {
  background-position: 0 -256px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-pl {
  background-position: 0 -304px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-pt-br {
  background-position: 0 -32px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-ru {
  background-position: 0 -320px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-ss-za {
  background-position: 0 -48px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-tr {
  background-position: 0 -80px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-24-zh-cn {
  background-position: 0 -208px;
}

/* line 10, /home/django/Emencia/cnct/compass/scss/components/_flags.scss */
.flags-24-sprite, .flags-24-ar-ma, .flags-24-cs, .flags-24-de, .flags-24-en-au, .flags-24-en-gb, .flags-24-en-nz, .flags-24-en-us, .flags-24-es-cl, .flags-24-es-co, .flags-24-es, .flags-24-fr, .flags-24-hu-si, .flags-24-it, .flags-24-ja, .flags-24-nl, .flags-24-pl, .flags-24-pt-br, .flags-24-ru, .flags-24-ss-za, .flags-24-tr, .flags-24-zh-cn {
  display: block;
  width: 24px;
  height: 16px;
  text-indent: -10000px;
}

/* line 202, flags/flags-35/*.png */
.flags-35-sprite, .flags-35-ar-ma, .flags-35-cs, .flags-35-de, .flags-35-en-au, .flags-35-en-gb, .flags-35-en-nz, .flags-35-en-us, .flags-35-es-cl, .flags-35-es-co, .flags-35-es, .flags-35-fr, .flags-35-hu-si, .flags-35-it, .flags-35-ja, .flags-35-nl, .flags-35-pl, .flags-35-pt-br, .flags-35-ru, .flags-35-ss-za, .flags-35-tr, .flags-35-zh-cn {
  background: url('../images/flags/flags-35-s63a3cb8602.png') no-repeat;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-ar-ma {
  background-position: 0 -192px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-cs {
  background-position: 0 -216px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-de {
  background-position: 0 -432px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-en-au {
  background-position: 0 -24px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-en-gb {
  background-position: 0 0;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-en-nz {
  background-position: 0 -72px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-en-us {
  background-position: 0 -120px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-es-cl {
  background-position: 0 -288px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-es-co {
  background-position: 0 -408px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-es {
  background-position: 0 -168px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-fr {
  background-position: 0 -360px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-hu-si {
  background-position: 0 -264px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-it {
  background-position: 0 -336px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-ja {
  background-position: 0 -312px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-nl {
  background-position: 0 -384px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-pl {
  background-position: 0 -456px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-pt-br {
  background-position: 0 -48px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-ru {
  background-position: 0 -480px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-ss-za {
  background-position: 0 -96px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-tr {
  background-position: 0 -144px;
}

/* line 60, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/compass-0.12.2/frameworks/compass/stylesheets/compass/utilities/sprites/_base.scss */
.flags-35-zh-cn {
  background-position: 0 -240px;
}

/* line 18, /home/django/Emencia/cnct/compass/scss/components/_flags.scss */
.flags-35-sprite, .flags-35-ar-ma, .flags-35-cs, .flags-35-de, .flags-35-en-au, .flags-35-en-gb, .flags-35-en-nz, .flags-35-en-us, .flags-35-es-cl, .flags-35-es-co, .flags-35-es, .flags-35-fr, .flags-35-hu-si, .flags-35-it, .flags-35-ja, .flags-35-nl, .flags-35-pl, .flags-35-pt-br, .flags-35-ru, .flags-35-ss-za, .flags-35-tr, .flags-35-zh-cn {
  display: block;
  width: 35px;
  height: 24px;
  text-indent: -10000px;
}

/*
 * Settings file containing Foundation settings
 * Inherit from the Foundation default settings, so uncomment only what you 
 * want to override
 */
/*
 * Add more screen width resolution for more granular breakpoints
 * 
 */
/* line 5, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
.responsive-left {
  float: none;
}
@media (min-width: 940px) {
  /* line 5, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
  .responsive-left {
    float: left;
  }
}

/* line 11, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
.responsive-right {
  float: none;
}
@media (min-width: 940px) {
  /* line 11, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
  .responsive-right {
    float: right;
  }
}

/* line 19, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
.force-clearfix {
  *zoom: 1;
}
/* line 4, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
.force-clearfix:before, .force-clearfix:after {
  content: " ";
  display: table;
}
/* line 5, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
.force-clearfix:after {
  clear: both;
}

/* line 22, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
.row-fluid {
  width: 100%;
  max-width: 100%;
  min-width: 0;
  padding: 0 15px;
}

/* line 29, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
.row.content {
  width: 1000px;
  max-width: 100%;
  margin: 0 auto;
  padding: 15px 0;
}

/* line 37, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
.columns.unpadded {
  padding: 0;
}

/* line 42, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
.relative-position {
  position: relative;
}

/* line 48, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
form.simple fieldset {
  border: 0;
  margin: 0;
  padding: 0;
}
/* line 53, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
form.simple legend {
  background-color: transparent;
  margin: 0;
  padding: 0;
}

/* line 61, /home/django/Emencia/cnct/compass/scss/common/_addons.scss */
.djangocms_text_ckeditor-text form {
  clear: both;
}

/* line 98, /home/django/Emencia/cnct/compass/scss/mixins/_base.scss */
img.centered, #content-main .album-grid-simple .item img {
  display: block;
  margin-left: auto;
  margin-right: auto;
}

/* line 104, /home/django/Emencia/cnct/compass/scss/mixins/_base.scss */
img.expanded {
  width: 100%;
  height: auto;
}

/*.brand{
    font-family: 'Radley', serif;
    font-weight: 400;
    font-size: 1.2em;
    
    &:after{
        content: "®";
        font-size: 0.3em;
        vertical-align: super;
    }
}*/
/*p .brand{
    &:after{
        content: "";
    }
}*/
/* line 52, ../../../compass/scss/minimal.scss */
#content-main {
  /*
   * Main content stylesheet
   */
}
/* line 134, /home/django/Emencia/cnct/compass/scss/mixins/_base.scss */
#content-main .nontabular-table {
  vertical-align: top;
}
/* line 137, /home/django/Emencia/cnct/compass/scss/mixins/_base.scss */
#content-main .table-fiftyfifty td {
  width: 50%;
}
/* line 141, /home/django/Emencia/cnct/compass/scss/mixins/_base.scss */
#content-main h1, #content-main h2, #content-main h3, #content-main h4, #content-main h5, #content-main h6 {
  font-weight: 400;
}
/* line 142, /home/django/Emencia/cnct/compass/scss/mixins/_base.scss */
#content-main h1 {
  font-size: 30px;
}
/* line 143, /home/django/Emencia/cnct/compass/scss/mixins/_base.scss */
#content-main h2 {
  font-size: 26px;
}
/* line 144, /home/django/Emencia/cnct/compass/scss/mixins/_base.scss */
#content-main h3 {
  font-size: 21px;
}
/* line 145, /home/django/Emencia/cnct/compass/scss/mixins/_base.scss */
#content-main h4 {
  font-size: 18px;
}
/* line 6, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main strong {
  color: #F8AD13;
}
/* line 10, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main img.expand {
  display: block;
  width: 100%;
}
/* line 15, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .row.black {
  color: #ffffff;
  background-color: #000000;
}
/* line 19, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .on-black {
  color: #ffffff;
  background-color: #000000;
}
/* line 23, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .on-black h2, #content-main .on-black h3, #content-main .on-black h4, #content-main .on-black h5, #content-main .on-black h6, #content-main .on-black p, #content-main .on-black li {
  color: white;
}
/* line 29, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .row.row-fluid.homepage {
  padding: 0;
}
/* line 32, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .row.row-fluid.homepage > .row {
  width: 1000px;
  max-width: 100%;
  margin: 0 auto;
  padding: 15px 0;
}
/* line 38, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .row.row-fluid.homepage > .row.unpadded {
  padding: 0;
}
/* line 45, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .button.black {
  background-color: #000000;
  border: 1px solid #000000;
  color: #FFFFFF;
}
/* line 50, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .button.black:hover, #content-main .button.black:focus {
  background-color: #404040;
}
/* line 56, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .button.plain-black {
  margin: 10px;
  padding: 15px 20px 15px 20px;
  font-size: 18px;
  font-weight: 600;
  color: white;
  text-transform: uppercase;
  background-color: black;
  border: 1px solid black;
  -webkit-box-shadow: rgba(15, 15, 15, 0.7) 0 0 5px;
  -moz-box-shadow: rgba(15, 15, 15, 0.7) 0 0 5px;
  box-shadow: rgba(15, 15, 15, 0.7) 0 0 5px;
}
@media (min-width: 768px) {
  /* line 56, /home/django/Emencia/cnct/compass/scss/_content.scss */
  #content-main .button.plain-black {
    margin: 20px 0;
    padding: 20px 35px;
    font-size: 24px;
  }
  /* line 72, /home/django/Emencia/cnct/compass/scss/_content.scss */
  #content-main .button.plain-black.radius-left {
    padding-right: 80px;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
  }
  /* line 77, /home/django/Emencia/cnct/compass/scss/_content.scss */
  #content-main .button.plain-black.radius-right {
    padding-left: 80px;
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
  }
}
/* line 83, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .button.plain-black .picto {
  font-weight: 600;
  color: white;
}
/* line 92, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-simple {
  *zoom: 1;
}
/* line 4, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
#content-main .album-grid-simple:before, #content-main .album-grid-simple:after {
  content: " ";
  display: table;
}
/* line 5, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
#content-main .album-grid-simple:after {
  clear: both;
}
/* line 95, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-simple .item {
  margin-bottom: 23px;
  text-align: center;
}
/* line 99, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-simple .item:last-child {
  float: left;
}
/* line 103, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-simple .item h3, #content-main .album-grid-simple .item h4, #content-main .album-grid-simple .item h5 {
  font-size: 13px;
  font-weight: 600;
}
/* line 108, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-simple .item p {
  margin-bottom: 0;
  font-size: 11px;
  font-weight: 400;
}
/* line 113, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-simple .item p + p {
  margin-top: 8px;
}
/* line 126, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-aside {
  *zoom: 1;
}
/* line 4, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
#content-main .album-grid-aside:before, #content-main .album-grid-aside:after {
  content: " ";
  display: table;
}
/* line 5, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
#content-main .album-grid-aside:after {
  clear: both;
}
/* line 129, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-aside .item {
  margin-bottom: 14px;
}
/* line 132, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-aside .item:last-child {
  float: left;
}
/* line 136, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-aside .item a {
  color: #000000;
}
/* line 140, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-aside .item .thumb {
  padding-left: 0;
  padding-right: 0;
}
/* line 145, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-aside .item .content {
  padding-top: 4%;
  padding-left: 10px;
  padding-right: 0;
}
/* line 150, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-aside .item .content p {
  margin: 0;
}
/* line 155, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .album-grid-aside .item .brand {
  display: block;
}
/* line 164, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .block-title {
  padding: 37px 17px 17px;
  font-size: 44px;
  font-weight: 300;
  color: #ffffff;
  background-color: #000000;
}
/* line 171, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .block-title .brand {
  display: block;
}
/* line 180, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro {
  border: 1px solid #CCCCCC;
  margin-bottom: 30px;
}
/* line 184, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro .visual {
  padding: 0;
  margin-bottom: 15px;
}
/* line 189, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro .item {
  margin-bottom: 15px;
  color: #9F9F9F;
}
/* line 193, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro .item h2 {
  font-size: 30px;
}
/* line 197, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro .item + .item {
  border-left: 2px solid #000000;
}
/* line 203, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro-2 {
  padding: 17px 17px 34px;
  position: relative;
  background-repeat: no-repeat;
  background-position: top left;
  -webkit-background-size: 100% 100%;
  -moz-background-size: 100% 100%;
  -o-background-size: 100% 100%;
  background-size: 100% 100%;
}
/* line 210, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro-2.unpadded {
  padding: 0;
}
/* line 214, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro-2 .background {
  display: none;
}
/* line 218, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro-2 .white-wrap {
  background-color: rgba(240, 240, 240, 0.5);
}
/* line 222, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro-2 .black-wrap {
  color: #ffffff;
  background-color: rgba(40, 40, 40, 0.5);
}
/* line 226, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro-2 .black-wrap h2, #content-main .index-intro-2 .black-wrap h3, #content-main .index-intro-2 .black-wrap h4, #content-main .index-intro-2 .black-wrap h5, #content-main .index-intro-2 .black-wrap div, #content-main .index-intro-2 .black-wrap dt, #content-main .index-intro-2 .black-wrap dd, #content-main .index-intro-2 .black-wrap li, #content-main .index-intro-2 .black-wrap p, #content-main .index-intro-2 .black-wrap blockquote, #content-main .index-intro-2 .black-wrap th, #content-main .index-intro-2 .black-wrap td {
  color: #ffffff;
}
/* line 232, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro-2 .content div, #content-main .index-intro-2 .content dt, #content-main .index-intro-2 .content dd, #content-main .index-intro-2 .content li, #content-main .index-intro-2 .content p, #content-main .index-intro-2 .content blockquote, #content-main .index-intro-2 .content th, #content-main .index-intro-2 .content td {
  font-size: 15px;
  font-weight: 400;
}
/* line 240, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro-2 .content ul li {
  position: relative;
}
/* line 243, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro-2 .content ul li[class^="icon-"]:before {
  font-size: 1.1em;
  left: -1.2em;
  line-height: 1em;
  position: absolute;
  top: 0;
  width: 1em;
}
/* line 254, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro-2 .content.white-on-black div, #content-main .index-intro-2 .content.white-on-black dt, #content-main .index-intro-2 .content.white-on-black dd, #content-main .index-intro-2 .content.white-on-black li, #content-main .index-intro-2 .content.white-on-black p, #content-main .index-intro-2 .content.white-on-black blockquote, #content-main .index-intro-2 .content.white-on-black th, #content-main .index-intro-2 .content.white-on-black td {
  color: #ffffff;
}
/* line 259, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-intro-2 .content + .content {
  margin-top: 17px;
}
/* line 266, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .mosaic-rows {
  margin-bottom: 15px;
}
/* line 269, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .mosaic-rows h2 {
  margin-bottom: 15px;
}
@media (max-width: 767px) {
  /* line 269, /home/django/Emencia/cnct/compass/scss/_content.scss */
  #content-main .mosaic-rows h2 {
    padding: 0 5px;
  }
}
/* line 277, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .mosaic-rows .underlined {
  border-bottom: 1px solid black;
}
@media (min-width: 768px) {
  /* line 281, /home/django/Emencia/cnct/compass/scss/_content.scss */
  #content-main .mosaic-rows .underlined strong {
    background-color: white;
    padding-right: 15px;
  }
}
/* line 289, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .mosaic-rows .row .visual.columns {
  padding: 5px;
}
/* line 292, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .mosaic-rows .row .visual.columns .badge-new {
  padding: 12px 6px;
  position: absolute;
  top: 10px;
  right: 10px;
  font-size: 12px;
  font-weight: 600;
  text-transform: uppercase;
  color: white;
  background-color: #F9F9F9;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #999999), color-stop(50%, #7c7c7c), color-stop(100%, #363636));
  background-image: -webkit-linear-gradient(#999999, #7c7c7c 50%, #363636);
  background-image: -moz-linear-gradient(#999999, #7c7c7c 50%, #363636);
  background-image: -o-linear-gradient(#999999, #7c7c7c 50%, #363636);
  background-image: linear-gradient(#999999, #7c7c7c 50%, #363636);
  border: 3px solid white;
  -webkit-border-radius: 20px;
  -moz-border-radius: 20px;
  -ms-border-radius: 20px;
  -o-border-radius: 20px;
  border-radius: 20px;
  text-shadow: #606060 0 0 3px;
  -webkit-box-shadow: #606060 0 2px 4px 1px;
  -moz-box-shadow: #606060 0 2px 4px 1px;
  box-shadow: #606060 0 2px 4px 1px;
}
/* line 309, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .mosaic-rows .row .visual.columns .bottomline {
  margin: 0;
  padding: 5px 8px;
  position: absolute;
  bottom: 5px;
  left: 5px;
  right: 5px;
  font-size: 14px;
  font-weight: 600;
  color: white;
  background-color: rgba(0, 0, 0, 0.7);
}
/* line 321, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .mosaic-rows .row .visual.columns .bottomline a {
  color: white;
}
/* line 330, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items {
  margin-bottom: 34px;
}
/* line 333, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item {
  position: relative;
  padding: 5px;
  /*&.news{
      .content{
          position: relative;
          padding: 0;
          z-index: 4000;
      }
          
      .entry-image{
          margin: 0;
          padding: 0;
          line-height: 0;
          
          img{
              display: block;
              margin: 0 auto;
          }
      }
      
      .entry-content{
          position: absolute;
          bottom: 0;
          padding: 7px 10px;
          height: 40%;
          overflow: hidden;
          color: #ffffff;
          background-color: #2C2D2D;
          
          h3{ font-size: 14px; color: #ffffff; margin-bottom: 5px;}
          h4{ font-size: 12px; color: #ffffff; margin-bottom: 5px;}
          h5, h6, p, li{ font-size: 11px; color: #999999; margin-bottom: 5px;}
          
          p{
              margin-bottom: 0;
              
              &+*{
                  margin-bottom: 5px;
              }
          }
          
          .entry-resume:after {
              bottom: 10px;
              font-weight: 700;
              position: absolute;
              right: 10px;
              font-family: 'fontawesome';
              font-size: 0.8em;
              @extend .icon-chevron-right:before;
          }
      }
  }*/
}
/* line 337, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item .wrap {
  position: relative;
  padding: 15px;
  -webkit-box-shadow: rgba(30, 30, 30, 0.7) 0 0 8px;
  -moz-box-shadow: rgba(30, 30, 30, 0.7) 0 0 8px;
  box-shadow: rgba(30, 30, 30, 0.7) 0 0 8px;
}
/* line 343, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item h2:first-child, #content-main .index-items .item h3:first-child, #content-main .index-items .item h4:first-child, #content-main .index-items .item h5:first-child, #content-main .index-items .item h6:first-child, #content-main .index-items .item p:first-child {
  margin-top: 0;
}
/* line 349, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item h2.badge,
#content-main .index-items .item h3.badge,
#content-main .index-items .item h4.badge {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 5000;
  padding: 10px 30px;
  color: white;
  font-size: 18px;
  font-weight: 600;
  text-transform: uppercase;
  background-color: black;
}
/* line 361, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item h2.badge a,
#content-main .index-items .item h3.badge a,
#content-main .index-items .item h4.badge a {
  color: white;
}
/* line 365, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item h2.badge + *,
#content-main .index-items .item h3.badge + *,
#content-main .index-items .item h4.badge + * {
  padding-top: 40px;
}
/* line 370, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item img {
  margin-bottom: 17px;
}
/* line 376, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item .content + div,
#content-main .index-items .item .content + p,
#content-main .index-items .item .content + ul {
  margin-top: 17px;
}
/* line 380, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item ul {
  list-style-type: none;
}
/* line 384, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item ul li {
  position: relative;
}
/* line 387, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item ul li:before {
  position: absolute;
  left: -1.2em;
  top: 0.6em;
  width: 1em;
  font-size: 0.8em;
  line-height: 1em;
  color: inherit;
  font-family: 'fontawesome';
  content: "\f054";
}
/* line 401, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item .black-wrap {
  padding: 0 0 5px 0;
  color: #ffffff;
  background-color: #000000;
}
/* line 406, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item .black-wrap p {
  padding-left: 10px;
  padding-right: 10px;
}
/* line 413, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item.flyer h2 {
  font-size: 22px;
}
/* line 416, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item.flyer h3 {
  font-size: 19px;
}
/* line 419, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item.flyer p, #content-main .index-items .item.flyer li {
  font-size: 12px;
  line-height: 1.1;
  margin: 0;
}
/* line 427, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item.news .wrap {
  padding: 0;
  /*background-color: #2C2D2D;*/
}
/* line 431, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item.news ul.feed {
  padding: 60px 15px 20px;
}
/* line 433, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item.news ul.feed li {
  color: #2C2D2D;
}
/* line 435, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item.news ul.feed li h3 {
  font-size: 12px;
  color: inherit;
}
/* line 439, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item.news ul.feed li:before {
  color: inherit;
  top: 0.1em;
}
/* line 443, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item.news ul.feed li a {
  color: inherit;
}
/* line 445, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .index-items .item.news ul.feed li a:hover {
  text-decoration: underline;
}
/* line 506, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-overview {
  *zoom: 1;
  position: relative;
  margin-bottom: 60px;
  -webkit-box-shadow: rgba(15, 15, 15, 0.6) 0 0 15px;
  -moz-box-shadow: rgba(15, 15, 15, 0.6) 0 0 15px;
  box-shadow: rgba(15, 15, 15, 0.6) 0 0 15px;
}
/* line 4, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
#content-main .intro-overview:before, #content-main .intro-overview:after {
  content: " ";
  display: table;
}
/* line 5, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
#content-main .intro-overview:after {
  clear: both;
}
/* line 512, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-overview.alternate {
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
}
/* line 518, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-overview .visual-overview p {
  margin: 0;
  line-height: 0;
}
/* line 524, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-overview .overview {
  padding-bottom: 10px;
  position: absolute;
  left: 0;
  bottom: -40px;
  z-index: 6000;
  width: 31%;
  background-color: white;
  -webkit-box-shadow: rgba(15, 15, 15, 0.7) 0 0 5px;
  -moz-box-shadow: rgba(15, 15, 15, 0.7) 0 0 5px;
  box-shadow: rgba(15, 15, 15, 0.7) 0 0 5px;
}
@media only screen and (max-width: 941px) {
  /* line 524, /home/django/Emencia/cnct/compass/scss/_content.scss */
  #content-main .intro-overview .overview {
    width: auto;
    position: static;
  }
}
/* line 538, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-overview .overview > * {
  padding-left: 30px;
  padding-right: 30px;
  font-size: 20px;
  line-height: 1.2;
}
/* line 545, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-overview .overview h2 {
  background-color: #000000;
  font-size: 26px;
  color: #FFFFFF;
  margin: 0 0 25px 0;
  padding: 25px 30px;
  text-transform: uppercase;
}
/* line 556, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-overview .overview-2 {
  padding: 0;
}
/* line 559, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-overview .overview-2 > * {
  padding: 25px;
}
/* line 562, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-overview .overview-2 p, #content-main .intro-overview .overview-2 li {
  font-size: 20px;
  line-height: 1.2;
}
/* line 567, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-overview .overview-2 h2 {
  margin: 0;
  padding: 35px 25px;
  font-size: 40px;
  color: #FFFFFF;
  text-transform: uppercase;
  background-color: #000000;
}
/* line 578, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .blockrow {
  *zoom: 1;
}
/* line 4, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
#content-main .blockrow:before, #content-main .blockrow:after {
  content: " ";
  display: table;
}
/* line 5, /home/django/.rvm/gems/ruby-1.9.3-p286/gems/zurb-foundation-3.2.5/scss/foundation/mixins/_clearfix.scss */
#content-main .blockrow:after {
  clear: both;
}
/* line 581, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .blockrow + .blockrow {
  margin-top: 20px;
}
/* line 585, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .blockrow .title {
  padding: 0;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(60%, #ffffff), color-stop(75%, #f5f5f5), color-stop(100%, #d7d7d7));
  background-image: -webkit-linear-gradient(#ffffff, #ffffff 60%, #f5f5f5 75%, #d7d7d7);
  background-image: -moz-linear-gradient(#ffffff, #ffffff 60%, #f5f5f5 75%, #d7d7d7);
  background-image: -o-linear-gradient(#ffffff, #ffffff 60%, #f5f5f5 75%, #d7d7d7);
  background-image: linear-gradient(#ffffff, #ffffff 60%, #f5f5f5 75%, #d7d7d7);
}
/* line 589, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .blockrow .title h2 {
  margin: 0;
  padding: 10px 0;
  text-transform: uppercase;
  background-image: -webkit-gradient(linear, 0% 50%, 100% 50%, color-stop(0%, #ffffff), color-stop(30%, rgba(255, 255, 255, 0)), color-stop(80%, rgba(255, 255, 255, 0)), color-stop(100%, #ffffff));
  background-image: -webkit-linear-gradient(left, #ffffff, rgba(255, 255, 255, 0) 30%, rgba(255, 255, 255, 0) 80%, #ffffff);
  background-image: -moz-linear-gradient(left, #ffffff, rgba(255, 255, 255, 0) 30%, rgba(255, 255, 255, 0) 80%, #ffffff);
  background-image: -o-linear-gradient(left, #ffffff, rgba(255, 255, 255, 0) 30%, rgba(255, 255, 255, 0) 80%, #ffffff);
  background-image: linear-gradient(left, #ffffff, rgba(255, 255, 255, 0) 30%, rgba(255, 255, 255, 0) 80%, #ffffff);
}
/* line 597, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .blockrow .content {
  padding-top: 35px;
  padding-right: 10%;
}
/* line 604, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .grid-band .visual {
  color: white;
  background-color: black;
  -webkit-box-shadow: rgba(15, 15, 15, 0.7) 0 0 5px;
  -moz-box-shadow: rgba(15, 15, 15, 0.7) 0 0 5px;
  box-shadow: rgba(15, 15, 15, 0.7) 0 0 5px;
}
/* line 609, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .grid-band .visual h2, #content-main .grid-band .visual h3, #content-main .grid-band .visual h4, #content-main .grid-band .visual h5, #content-main .grid-band .visual h6 {
  margin: 0;
  padding: 10px 20px;
  color: inherit;
}
/* line 615, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .grid-band .content {
  padding: 10px 25px;
}
/* line 620, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-block {
  padding: 10px;
  background-color: #FEFEFE;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #fefefe), color-stop(100%, #d4d4d4));
  background-image: -webkit-linear-gradient(#fefefe, #d4d4d4);
  background-image: -moz-linear-gradient(#fefefe, #d4d4d4);
  background-image: -o-linear-gradient(#fefefe, #d4d4d4);
  background-image: linear-gradient(#fefefe, #d4d4d4);
  border-bottom: 1px solid #8E8E8E;
}
/* line 626, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-block strong {
  color: inherit;
}
/* line 630, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-block.dark-grey {
  color: white;
  background-color: #171717;
  background-image: -webkit-gradient(linear, 0% 50%, 100% 50%, color-stop(0%, #9e9e9e), color-stop(40%, #171717), color-stop(60%, #171717), color-stop(100%, #9e9e9e));
  background-image: -webkit-linear-gradient(left, #9e9e9e, #171717 40%, #171717 60%, #9e9e9e);
  background-image: -moz-linear-gradient(left, #9e9e9e, #171717 40%, #171717 60%, #9e9e9e);
  background-image: -o-linear-gradient(left, #9e9e9e, #171717 40%, #171717 60%, #9e9e9e);
  background-image: linear-gradient(left, #9e9e9e, #171717 40%, #171717 60%, #9e9e9e);
  border-bottom: 1px solid #8A8A8;
}
/* line 636, /home/django/Emencia/cnct/compass/scss/_content.scss */
#content-main .intro-block.dark-grey h2, #content-main .intro-block.dark-grey h3, #content-main .intro-block.dark-grey h4, #content-main .intro-block.dark-grey h5, #content-main .intro-block.dark-grey h6, #content-main .intro-block.dark-grey strong {
  color: inherit;
}
